# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/integrations/v1/database.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/integrations/v1/database.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'nodus/v1/integrations/v1/database.proto\x12\x18nodus.v1.integrations.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/duration.proto\"\xcd\x04\n\x0e\x44\x61tabaseConfig\x12K\n\rdatabase_type\x18\x01 \x01(\x0e\x32&.nodus.v1.integrations.v1.DatabaseTypeR\x0c\x64\x61tabaseType\x12<\n\x1a\x63onnection_string_template\x18\x02 \x01(\tR\x18\x63onnectionStringTemplate\x12\x12\n\x04host\x18\x03 \x01(\tR\x04host\x12\x12\n\x04port\x18\x04 \x01(\x05R\x04port\x12\x1a\n\x08\x64\x61tabase\x18\x05 \x01(\tR\x08\x64\x61tabase\x12\x1a\n\x08username\x18\x06 \x01(\tR\x08username\x12\x34\n\x16password_credential_id\x18\x07 \x01(\tR\x14passwordCredentialId\x12\x17\n\x07use_ssl\x18\x08 \x01(\x08R\x06useSsl\x12k\n\x11\x63onnection_params\x18\t \x03(\x0b\x32>.nodus.v1.integrations.v1.DatabaseConfig.ConnectionParamsEntryR\x10\x63onnectionParams\x12O\n\x0bpool_config\x18\n \x01(\x0b\x32..nodus.v1.integrations.v1.ConnectionPoolConfigR\npoolConfig\x1a\x43\n\x15\x43onnectionParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xae\x02\n\x14\x43onnectionPoolConfig\x12\'\n\x0fmax_connections\x18\x01 \x01(\x05R\x0emaxConnections\x12\'\n\x0fmin_connections\x18\x02 \x01(\x05R\x0eminConnections\x12H\n\x12\x63onnection_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11\x63onnectionTimeout\x12<\n\x0cidle_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bidleTimeout\x12<\n\x0cmax_lifetime\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxLifetime\"\xd5\x03\n\x14VectorDatabaseConfig\x12K\n\rdatabase_type\x18\x01 \x01(\x0e\x32&.nodus.v1.integrations.v1.DatabaseTypeR\x0c\x64\x61tabaseType\x12\x31\n\x15\x61pi_key_credential_id\x18\x02 \x01(\tR\x12\x61piKeyCredentialId\x12 \n\x0b\x65nvironment\x18\x03 \x01(\tR\x0b\x65nvironment\x12\x1d\n\nindex_name\x18\x04 \x01(\tR\tindexName\x12\x1c\n\tdimension\x18\x05 \x01(\x05R\tdimension\x12\x16\n\x06metric\x18\x06 \x01(\tR\x06metric\x12k\n\x0fmetadata_config\x18\x07 \x03(\x0b\x32\x42.nodus.v1.integrations.v1.VectorDatabaseConfig.MetadataConfigEntryR\x0emetadataConfig\x1aY\n\x13MetadataConfigEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\"\xdc\x01\n\x0bQueryConfig\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12\x37\n\nparameters\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\nparameters\x12\x14\n\x05limit\x18\x03 \x01(\x05R\x05limit\x12\x16\n\x06offset\x18\x04 \x01(\x05R\x06offset\x12\x33\n\x07timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12\x1b\n\tread_only\x18\x06 \x01(\x08R\x08readOnly*\xa7\x02\n\x0c\x44\x61tabaseType\x12\x1d\n\x19\x44\x41TABASE_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x44\x41TABASE_TYPE_POSTGRESQL\x10\x01\x12\x17\n\x13\x44\x41TABASE_TYPE_MYSQL\x10\x02\x12\x18\n\x14\x44\x41TABASE_TYPE_SQLITE\x10\x03\x12\x19\n\x15\x44\x41TABASE_TYPE_MONGODB\x10\x04\x12\x17\n\x13\x44\x41TABASE_TYPE_REDIS\x10\x05\x12\x1f\n\x1b\x44\x41TABASE_TYPE_ELASTICSEARCH\x10\x06\x12\x1a\n\x16\x44\x41TABASE_TYPE_PINECONE\x10\x07\x12\x18\n\x14\x44\x41TABASE_TYPE_QDRANT\x10\x08\x12\x1c\n\x18\x44\x41TABASE_TYPE_CLICKHOUSE\x10\tB\x85\x02\n\x1c\x63om.nodus.v1.integrations.v1B\rDatabaseProtoP\x01ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\xa2\x02\x03NVI\xaa\x02\x18Nodus.V1.Integrations.V1\xca\x02\x18Nodus\\V1\\Integrations\\V1\xe2\x02$Nodus\\V1\\Integrations\\V1\\GPBMetadata\xea\x02\x1bNodus::V1::Integrations::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.integrations.v1.database_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.nodus.v1.integrations.v1B\rDatabaseProtoP\001ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\242\002\003NVI\252\002\030Nodus.V1.Integrations.V1\312\002\030Nodus\\V1\\Integrations\\V1\342\002$Nodus\\V1\\Integrations\\V1\\GPBMetadata\352\002\033Nodus::V1::Integrations::V1'
  _globals['_DATABASECONFIG_CONNECTIONPARAMSENTRY']._loaded_options = None
  _globals['_DATABASECONFIG_CONNECTIONPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_VECTORDATABASECONFIG_METADATACONFIGENTRY']._loaded_options = None
  _globals['_VECTORDATABASECONFIG_METADATACONFIGENTRY']._serialized_options = b'8\001'
  _globals['_DATABASETYPE']._serialized_start=1724
  _globals['_DATABASETYPE']._serialized_end=2019
  _globals['_DATABASECONFIG']._serialized_start=132
  _globals['_DATABASECONFIG']._serialized_end=721
  _globals['_DATABASECONFIG_CONNECTIONPARAMSENTRY']._serialized_start=654
  _globals['_DATABASECONFIG_CONNECTIONPARAMSENTRY']._serialized_end=721
  _globals['_CONNECTIONPOOLCONFIG']._serialized_start=724
  _globals['_CONNECTIONPOOLCONFIG']._serialized_end=1026
  _globals['_VECTORDATABASECONFIG']._serialized_start=1029
  _globals['_VECTORDATABASECONFIG']._serialized_end=1498
  _globals['_VECTORDATABASECONFIG_METADATACONFIGENTRY']._serialized_start=1409
  _globals['_VECTORDATABASECONFIG_METADATACONFIGENTRY']._serialized_end=1498
  _globals['_QUERYCONFIG']._serialized_start=1501
  _globals['_QUERYCONFIG']._serialized_end=1721
# @@protoc_insertion_point(module_scope)
