# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/common.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from spounge.polykey.v2 import key_types_pb2 as polykey_dot_v2_dot_key__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17polykey/v2/common.proto\x12\npolykey.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1apolykey/v2/key_types.proto\"\xc2\x01\n\x10RequesterContext\x12\'\n\x0f\x63lient_identity\x18\x01 \x01(\tR\x0e\x63lientIdentity\x12\x37\n\x17\x63\x65rtificate_fingerprint\x18\x02 \x01(\tR\x16\x63\x65rtificateFingerprint\x12%\n\x0e\x61pplication_id\x18\x03 \x01(\tR\rapplicationId\x12%\n\x0e\x63orrelation_id\x18\x04 \x01(\tR\rcorrelationId\"\xc2\x03\n\x10\x41\x63\x63\x65ssAttributes\x12 \n\x0b\x65nvironment\x18\x01 \x01(\tR\x0b\x65nvironment\x12!\n\x0cnetwork_zone\x18\x02 \x01(\tR\x0bnetworkZone\x12+\n\x11geographic_region\x18\x03 \x01(\tR\x10geographicRegion\x12=\n\x0crequest_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0brequestTime\x12\x1f\n\x0btime_window\x18\x05 \x01(\tR\ntimeWindow\x12\x14\n\x05roles\x18\x06 \x03(\tR\x05roles\x12 \n\x0bpermissions\x18\x07 \x03(\tR\x0bpermissions\x12_\n\x11\x63ustom_attributes\x18\x08 \x03(\x0b\x32\x32.polykey.v2.AccessAttributes.CustomAttributesEntryR\x10\x63ustomAttributes\x1a\x43\n\x15\x43ustomAttributesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x9c\x07\n\x0bKeyMetadata\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12.\n\x08key_type\x18\x02 \x01(\x0e\x32\x13.polykey.v2.KeyTypeR\x07keyType\x12-\n\x06status\x18\x03 \x01(\x0e\x32\x15.polykey.v2.KeyStatusR\x06status\x12\x18\n\x07version\x18\x04 \x01(\x05R\x07version\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x39\n\nexpires_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12\x44\n\x10last_accessed_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0elastAccessedAt\x12)\n\x10\x63reator_identity\x18\t \x01(\tR\x0f\x63reatorIdentity\x12/\n\x13\x61uthorized_contexts\x18\n \x03(\tR\x12\x61uthorizedContexts\x12T\n\x0f\x61\x63\x63\x65ss_policies\x18\x0b \x03(\x0b\x32+.polykey.v2.KeyMetadata.AccessPoliciesEntryR\x0e\x61\x63\x63\x65ssPolicies\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12\x35\n\x04tags\x18\r \x03(\x0b\x32!.polykey.v2.KeyMetadata.TagsEntryR\x04tags\x12/\n\x13\x64\x61ta_classification\x18\x0e \x01(\tR\x12\x64\x61taClassification\x12+\n\x11metadata_checksum\x18\x0f \x01(\tR\x10metadataChecksum\x12!\n\x0c\x61\x63\x63\x65ss_count\x18\x10 \x01(\x03R\x0b\x61\x63\x63\x65ssCount\x1a\x41\n\x13\x41\x63\x63\x65ssPoliciesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc5\x01\n\x0bKeyMaterial\x12,\n\x12\x65ncrypted_key_data\x18\x01 \x01(\x0cR\x10\x65ncryptedKeyData\x12\x31\n\x14\x65ncryption_algorithm\x18\x02 \x01(\tR\x13\x65ncryptionAlgorithm\x12\x32\n\x15key_derivation_params\x18\x03 \x01(\tR\x13keyDerivationParams\x12!\n\x0ckey_checksum\x18\x04 \x01(\tR\x0bkeyChecksum\"\xd6\x01\n\x12\x41\x63\x63\x65ssHistoryEntry\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\'\n\x0f\x63lient_identity\x18\x02 \x01(\tR\x0e\x63lientIdentity\x12\x1c\n\toperation\x18\x03 \x01(\tR\toperation\x12\x18\n\x07success\x18\x04 \x01(\x08R\x07success\x12%\n\x0e\x63orrelation_id\x18\x05 \x01(\tR\rcorrelationId\"\xe6\x02\n\x0cPolicyDetail\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\x12\x1f\n\x0bpolicy_type\x18\x02 \x01(\tR\npolicyType\x12O\n\rpolicy_params\x18\x03 \x03(\x0b\x32*.polykey.v2.PolicyDetail.PolicyParamsEntryR\x0cpolicyParams\x12\x41\n\x0e\x65\x66\x66\x65\x63tive_from\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\reffectiveFrom\x12\x43\n\x0f\x65\x66\x66\x65\x63tive_until\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x65\x66\x66\x65\x63tiveUntil\x1a?\n\x11PolicyParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xa8\x01\n\x0e\x63om.polykey.v2B\x0b\x43ommonProtoP\x01Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\013CommonProtoP\001Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_ACCESSATTRIBUTES_CUSTOMATTRIBUTESENTRY']._loaded_options = None
  _globals['_ACCESSATTRIBUTES_CUSTOMATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_KEYMETADATA_ACCESSPOLICIESENTRY']._loaded_options = None
  _globals['_KEYMETADATA_ACCESSPOLICIESENTRY']._serialized_options = b'8\001'
  _globals['_KEYMETADATA_TAGSENTRY']._loaded_options = None
  _globals['_KEYMETADATA_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_POLICYDETAIL_POLICYPARAMSENTRY']._loaded_options = None
  _globals['_POLICYDETAIL_POLICYPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_REQUESTERCONTEXT']._serialized_start=101
  _globals['_REQUESTERCONTEXT']._serialized_end=295
  _globals['_ACCESSATTRIBUTES']._serialized_start=298
  _globals['_ACCESSATTRIBUTES']._serialized_end=748
  _globals['_ACCESSATTRIBUTES_CUSTOMATTRIBUTESENTRY']._serialized_start=681
  _globals['_ACCESSATTRIBUTES_CUSTOMATTRIBUTESENTRY']._serialized_end=748
  _globals['_KEYMETADATA']._serialized_start=751
  _globals['_KEYMETADATA']._serialized_end=1675
  _globals['_KEYMETADATA_ACCESSPOLICIESENTRY']._serialized_start=1553
  _globals['_KEYMETADATA_ACCESSPOLICIESENTRY']._serialized_end=1618
  _globals['_KEYMETADATA_TAGSENTRY']._serialized_start=1620
  _globals['_KEYMETADATA_TAGSENTRY']._serialized_end=1675
  _globals['_KEYMATERIAL']._serialized_start=1678
  _globals['_KEYMATERIAL']._serialized_end=1875
  _globals['_ACCESSHISTORYENTRY']._serialized_start=1878
  _globals['_ACCESSHISTORYENTRY']._serialized_end=2092
  _globals['_POLICYDETAIL']._serialized_start=2095
  _globals['_POLICYDETAIL']._serialized_end=2453
  _globals['_POLICYDETAIL_POLICYPARAMSENTRY']._serialized_start=2390
  _globals['_POLICYDETAIL_POLICYPARAMSENTRY']._serialized_end=2453
# @@protoc_insertion_point(module_scope)
