# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/nodes/v1/execution.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/nodes/v1/execution.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from spounge.nodus.v1.common.v1 import types_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_types__pb2
from spounge.nodus.v1.common.v1 import resources_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_resources__pb2
from spounge.nodus.v1.common.v1 import errors_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_errors__pb2
from spounge.nodus.v1.nodes.v1 import direct_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_direct__pb2
from spounge.nodus.v1.nodes.v1 import reasoning_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_reasoning__pb2
from spounge.nodus.v1.nodes.v1 import autonomous_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_autonomous__pb2
from spounge.nodus.v1.nodes.v1 import webhook_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_webhook__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nodus/v1/nodes/v1/execution.proto\x12\x11nodus.v1.nodes.v1\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1enodus/v1/common/v1/types.proto\x1a\"nodus/v1/common/v1/resources.proto\x1a\x1fnodus/v1/common/v1/errors.proto\x1a\x1enodus/v1/nodes/v1/direct.proto\x1a!nodus/v1/nodes/v1/reasoning.proto\x1a\"nodus/v1/nodes/v1/autonomous.proto\x1a\x1fnodus/v1/nodes/v1/webhook.proto\"\xca\x05\n\x12\x45xecuteNodeRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12\x39\n\tnode_type\x18\x03 \x01(\x0e\x32\x1c.nodus.v1.common.v1.NodeTypeR\x08nodeType\x12\x33\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12\x1f\n\x0bmax_retries\x18\x05 \x01(\x05R\nmaxRetries\x12J\n\rdirect_config\x18\n \x01(\x0b\x32#.nodus.v1.nodes.v1.DirectNodeConfigH\x00R\x0c\x64irectConfig\x12S\n\x10reasoning_config\x18\x0b \x01(\x0b\x32&.nodus.v1.nodes.v1.ReasoningNodeConfigH\x00R\x0freasoningConfig\x12V\n\x11\x61utonomous_config\x18\x0c \x01(\x0b\x32\'.nodus.v1.nodes.v1.AutonomousNodeConfigH\x00R\x10\x61utonomousConfig\x12M\n\x0ewebhook_config\x18\r \x01(\x0b\x32$.nodus.v1.nodes.v1.WebhookNodeConfigH\x00R\rwebhookConfig\x12Q\n\x11\x65xecution_context\x18\x14 \x01(\x0b\x32$.nodus.v1.common.v1.ExecutionContextR\x10\x65xecutionContext\x12=\n\x0crequested_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0brequestedAtB\r\n\x0bnode_config\"\x92\x04\n\x13\x45xecuteNodeResponse\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12;\n\x06status\x18\x03 \x01(\x0e\x32#.nodus.v1.common.v1.ExecutionStatusR\x06status\x12\x35\n\x0bresult_data\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyR\nresultData\x12@\n\x08metadata\x18\x05 \x01(\x0b\x32$.nodus.v1.nodes.v1.ExecutionMetadataR\x08metadata\x12\x38\n\x05\x65rror\x18\x06 \x01(\x0b\x32\".nodus.v1.common.v1.ExecutionErrorR\x05\x65rror\x12@\n\x0e\x65xecution_time\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\rexecutionTime\x12N\n\x0eresource_usage\x18\x08 \x01(\x0b\x32\'.nodus.v1.common.v1.ResourceConsumptionR\rresourceUsage\x12=\n\x0c\x63ompleted_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63ompletedAt\"\xac\x05\n\x11\x45xecutionMetadata\x12I\n\x0f\x65xecution_steps\x18\x01 \x03(\x0b\x32 .nodus.v1.nodes.v1.ExecutionStepR\x0e\x65xecutionSteps\x12)\n\x10total_iterations\x18\x02 \x01(\x05R\x0ftotalIterations\x12)\n\x10tool_invocations\x18\x03 \x01(\x05R\x0ftoolInvocations\x12I\n\x13llm_processing_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11llmProcessingTime\x12I\n\x13tool_execution_time\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11toolExecutionTime\x12H\n\x12serialization_time\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11serializationTime\x12)\n\x10\x63onfidence_score\x18\x07 \x01(\x02R\x0f\x63onfidenceScore\x12-\n\x12termination_reason\x18\x08 \x01(\tR\x11terminationReason\x12\x1a\n\x08warnings\x18\t \x03(\tR\x08warnings\x12^\n\x0e\x63ustom_metrics\x18\n \x03(\x0b\x32\x37.nodus.v1.nodes.v1.ExecutionMetadata.CustomMetricsEntryR\rcustomMetrics\x1a@\n\x12\x43ustomMetricsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc1\x03\n\rExecutionStep\x12\x1f\n\x0bstep_number\x18\x01 \x01(\x05R\nstepNumber\x12\x38\n\tstep_type\x18\x02 \x01(\x0e\x32\x1b.nodus.v1.nodes.v1.StepTypeR\x08stepType\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x33\n\nstep_input\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyR\tstepInput\x12\x35\n\x0bstep_output\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyR\nstepOutput\x12>\n\rstep_duration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cstepDuration\x12\x44\n\x0bstep_status\x18\x07 \x01(\x0e\x32#.nodus.v1.common.v1.ExecutionStatusR\nstepStatus\x12\x41\n\nstep_error\x18\x08 \x01(\x0b\x32\".nodus.v1.common.v1.ExecutionErrorR\tstepError\"\xd0\x05\n\x18\x45xecuteNodeStreamRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12\x39\n\tnode_type\x18\x03 \x01(\x0e\x32\x1c.nodus.v1.common.v1.NodeTypeR\x08nodeType\x12\x33\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12\x1f\n\x0bmax_retries\x18\x05 \x01(\x05R\nmaxRetries\x12J\n\rdirect_config\x18\n \x01(\x0b\x32#.nodus.v1.nodes.v1.DirectNodeConfigH\x00R\x0c\x64irectConfig\x12S\n\x10reasoning_config\x18\x0b \x01(\x0b\x32&.nodus.v1.nodes.v1.ReasoningNodeConfigH\x00R\x0freasoningConfig\x12V\n\x11\x61utonomous_config\x18\x0c \x01(\x0b\x32\'.nodus.v1.nodes.v1.AutonomousNodeConfigH\x00R\x10\x61utonomousConfig\x12M\n\x0ewebhook_config\x18\r \x01(\x0b\x32$.nodus.v1.nodes.v1.WebhookNodeConfigH\x00R\rwebhookConfig\x12Q\n\x11\x65xecution_context\x18\x14 \x01(\x0b\x32$.nodus.v1.common.v1.ExecutionContextR\x10\x65xecutionContext\x12=\n\x0crequested_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0brequestedAtB\r\n\x0bnode_config\"\x98\x04\n\x19\x45xecuteNodeStreamResponse\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x17\n\x07node_id\x18\x02 \x01(\tR\x06nodeId\x12;\n\x06status\x18\x03 \x01(\x0e\x32#.nodus.v1.common.v1.ExecutionStatusR\x06status\x12\x35\n\x0bresult_data\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyR\nresultData\x12@\n\x08metadata\x18\x05 \x01(\x0b\x32$.nodus.v1.nodes.v1.ExecutionMetadataR\x08metadata\x12\x38\n\x05\x65rror\x18\x06 \x01(\x0b\x32\".nodus.v1.common.v1.ExecutionErrorR\x05\x65rror\x12@\n\x0e\x65xecution_time\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\rexecutionTime\x12N\n\x0eresource_usage\x18\x08 \x01(\x0b\x32\'.nodus.v1.common.v1.ResourceConsumptionR\rresourceUsage\x12=\n\x0c\x63ompleted_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63ompletedAt*\xb4\x01\n\x08StepType\x12\x19\n\x15STEP_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13STEP_TYPE_REASONING\x10\x01\x12\x1d\n\x19STEP_TYPE_TOOL_INVOCATION\x10\x02\x12\x1f\n\x1bSTEP_TYPE_RESULT_PROCESSING\x10\x03\x12\x1a\n\x16STEP_TYPE_STATE_UPDATE\x10\x04\x12\x18\n\x14STEP_TYPE_VALIDATION\x10\x05\x42\xd5\x01\n\x15\x63om.nodus.v1.nodes.v1B\x0e\x45xecutionProtoP\x01ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\xa2\x02\x03NVN\xaa\x02\x11Nodus.V1.Nodes.V1\xca\x02\x11Nodus\\V1\\Nodes\\V1\xe2\x02\x1dNodus\\V1\\Nodes\\V1\\GPBMetadata\xea\x02\x14Nodus::V1::Nodes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.nodes.v1.execution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.nodus.v1.nodes.v1B\016ExecutionProtoP\001ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\242\002\003NVN\252\002\021Nodus.V1.Nodes.V1\312\002\021Nodus\\V1\\Nodes\\V1\342\002\035Nodus\\V1\\Nodes\\V1\\GPBMetadata\352\002\024Nodus::V1::Nodes::V1'
  _globals['_EXECUTIONMETADATA_CUSTOMMETRICSENTRY']._loaded_options = None
  _globals['_EXECUTIONMETADATA_CUSTOMMETRICSENTRY']._serialized_options = b'8\001'
  _globals['_STEPTYPE']._serialized_start=4037
  _globals['_STEPTYPE']._serialized_end=4217
  _globals['_EXECUTENODEREQUEST']._serialized_start=386
  _globals['_EXECUTENODEREQUEST']._serialized_end=1100
  _globals['_EXECUTENODERESPONSE']._serialized_start=1103
  _globals['_EXECUTENODERESPONSE']._serialized_end=1633
  _globals['_EXECUTIONMETADATA']._serialized_start=1636
  _globals['_EXECUTIONMETADATA']._serialized_end=2320
  _globals['_EXECUTIONMETADATA_CUSTOMMETRICSENTRY']._serialized_start=2256
  _globals['_EXECUTIONMETADATA_CUSTOMMETRICSENTRY']._serialized_end=2320
  _globals['_EXECUTIONSTEP']._serialized_start=2323
  _globals['_EXECUTIONSTEP']._serialized_end=2772
  _globals['_EXECUTENODESTREAMREQUEST']._serialized_start=2775
  _globals['_EXECUTENODESTREAMREQUEST']._serialized_end=3495
  _globals['_EXECUTENODESTREAMRESPONSE']._serialized_start=3498
  _globals['_EXECUTENODESTREAMRESPONSE']._serialized_end=4034
# @@protoc_insertion_point(module_scope)
