# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/integrations/v1/webhook.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/integrations/v1/webhook.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nodus/v1/integrations/v1/webhook.proto\x12\x18nodus.v1.integrations.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa8\x03\n\x0fWebhookCallback\x12P\n\x07headers\x18\x01 \x03(\x0b\x32\x36.nodus.v1.integrations.v1.WebhookCallback.HeadersEntryR\x07headers\x12]\n\x0cquery_params\x18\x02 \x03(\x0b\x32:.nodus.v1.integrations.v1.WebhookCallback.QueryParamsEntryR\x0bqueryParams\x12+\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x62ody\x12;\n\x0breceived_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nreceivedAt\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a>\n\x10QueryParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x84\x02\n\x1c\x63om.nodus.v1.integrations.v1B\x0cWebhookProtoP\x01ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\xa2\x02\x03NVI\xaa\x02\x18Nodus.V1.Integrations.V1\xca\x02\x18Nodus\\V1\\Integrations\\V1\xe2\x02$Nodus\\V1\\Integrations\\V1\\GPBMetadata\xea\x02\x1bNodus::V1::Integrations::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.integrations.v1.webhook_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.nodus.v1.integrations.v1B\014WebhookProtoP\001ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\242\002\003NVI\252\002\030Nodus.V1.Integrations.V1\312\002\030Nodus\\V1\\Integrations\\V1\342\002$Nodus\\V1\\Integrations\\V1\\GPBMetadata\352\002\033Nodus::V1::Integrations::V1'
  _globals['_WEBHOOKCALLBACK_HEADERSENTRY']._loaded_options = None
  _globals['_WEBHOOKCALLBACK_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_WEBHOOKCALLBACK_QUERYPARAMSENTRY']._loaded_options = None
  _globals['_WEBHOOKCALLBACK_QUERYPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_WEBHOOKCALLBACK']._serialized_start=132
  _globals['_WEBHOOKCALLBACK']._serialized_end=556
  _globals['_WEBHOOKCALLBACK_HEADERSENTRY']._serialized_start=434
  _globals['_WEBHOOKCALLBACK_HEADERSENTRY']._serialized_end=492
  _globals['_WEBHOOKCALLBACK_QUERYPARAMSENTRY']._serialized_start=494
  _globals['_WEBHOOKCALLBACK_QUERYPARAMSENTRY']._serialized_end=556
# @@protoc_insertion_point(module_scope)
