# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/metrics.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/metrics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18polykey/v2/metrics.proto\x12\npolykey.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa6\x03\n\x0eServiceMetrics\x12\x37\n\x18\x61verage_response_time_ms\x18\x01 \x01(\x01R\x15\x61verageResponseTimeMs\x12.\n\x13requests_per_second\x18\x02 \x01(\x03R\x11requestsPerSecond\x12,\n\x12\x65rror_rate_percent\x18\x03 \x01(\x01R\x10\x65rrorRatePercent\x12*\n\x11\x63pu_usage_percent\x18\x04 \x01(\x01R\x0f\x63puUsagePercent\x12\x30\n\x14memory_usage_percent\x18\x05 \x01(\x01R\x12memoryUsagePercent\x12*\n\x11\x61\x63tive_keys_count\x18\x06 \x01(\x03R\x0f\x61\x63tiveKeysCount\x12\x34\n\x16total_requests_handled\x18\x07 \x01(\x03R\x14totalRequestsHandled\x12=\n\x0cuptime_since\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0buptimeSince\"\x83\x02\n\x13HealthCheckResponse\x12\x30\n\x06status\x18\x01 \x01(\x0e\x32\x18.polykey.v2.HealthStatusR\x06status\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x34\n\x07metrics\x18\x03 \x01(\x0b\x32\x1a.polykey.v2.ServiceMetricsR\x07metrics\x12\'\n\x0fservice_version\x18\x04 \x01(\tR\x0eserviceVersion\x12!\n\x0c\x62uild_commit\x18\x05 \x01(\tR\x0b\x62uildCommit*\x81\x01\n\x0cHealthStatus\x12\x1d\n\x19HEALTH_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15HEALTH_STATUS_HEALTHY\x10\x01\x12\x1a\n\x16HEALTH_STATUS_DEGRADED\x10\x02\x12\x1b\n\x17HEALTH_STATUS_UNHEALTHY\x10\x03\x42\xa9\x01\n\x0e\x63om.polykey.v2B\x0cMetricsProtoP\x01Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.metrics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\014MetricsProtoP\001Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_HEALTHSTATUS']._serialized_start=761
  _globals['_HEALTHSTATUS']._serialized_end=890
  _globals['_SERVICEMETRICS']._serialized_start=74
  _globals['_SERVICEMETRICS']._serialized_end=496
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=499
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=758
# @@protoc_insertion_point(module_scope)
