# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/auth_gateway_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'api/v2/auth_gateway_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.auth.v2 import auth_service_pb2 as auth_dot_v2_dot_auth__service__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!api/v2/auth_gateway_service.proto\x12\x06\x61pi.v2\x1a\x1a\x61uth/v2/auth_service.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"\\\n\x1e\x41uthGatewayServiceLoginRequest\x12:\n\rlogin_request\x18\x01 \x01(\x0b\x32\x15.auth.v2.LoginRequestR\x0cloginRequest\"`\n\x1f\x41uthGatewayServiceLoginResponse\x12=\n\x0elogin_response\x18\x01 \x01(\x0b\x32\x16.auth.v2.LoginResponseR\rloginResponse\"y\n%AuthGatewayServiceRefreshTokenRequest\x12P\n\x15refresh_token_request\x18\x01 \x01(\x0b\x32\x1c.auth.v2.RefreshTokenRequestR\x13refreshTokenRequest\"}\n&AuthGatewayServiceRefreshTokenResponse\x12S\n\x16refresh_token_response\x18\x01 \x01(\x0b\x32\x1d.auth.v2.RefreshTokenResponseR\x14refreshTokenResponse\"O\n\x1f\x41uthGatewayServiceLogoutRequest\x12,\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x05\x65mpty\"d\n AuthGatewayServiceLogoutResponse\x12@\n\x0flogout_response\x18\x01 \x01(\x0b\x32\x17.auth.v2.LogoutResponseR\x0elogoutResponse2\x8f\x03\n\x12\x41uthGatewayService\x12s\n\x05Login\x12&.api.v2.AuthGatewayServiceLoginRequest\x1a\'.api.v2.AuthGatewayServiceLoginResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v2/auth/login:\x01*\x12\x8a\x01\n\x0cRefreshToken\x12-.api.v2.AuthGatewayServiceRefreshTokenRequest\x1a..api.v2.AuthGatewayServiceRefreshTokenResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v2/auth/refresh:\x01*\x12w\n\x06Logout\x12\'.api.v2.AuthGatewayServiceLogoutRequest\x1a(.api.v2.AuthGatewayServiceLogoutResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v2/auth/logout:\x01*B\x98\x01\n\ncom.api.v2B\x17\x41uthGatewayServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v2.auth_gateway_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.api.v2B\027AuthGatewayServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2'
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['Login']._loaded_options = None
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['Login']._serialized_options = b'\202\323\344\223\002\023\"\016/v2/auth/login:\001*'
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['RefreshToken']._loaded_options = None
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['RefreshToken']._serialized_options = b'\202\323\344\223\002\025\"\020/v2/auth/refresh:\001*'
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['Logout']._loaded_options = None
  _globals['_AUTHGATEWAYSERVICE'].methods_by_name['Logout']._serialized_options = b'\202\323\344\223\002\024\"\017/v2/auth/logout:\001*'
  _globals['_AUTHGATEWAYSERVICELOGINREQUEST']._serialized_start=132
  _globals['_AUTHGATEWAYSERVICELOGINREQUEST']._serialized_end=224
  _globals['_AUTHGATEWAYSERVICELOGINRESPONSE']._serialized_start=226
  _globals['_AUTHGATEWAYSERVICELOGINRESPONSE']._serialized_end=322
  _globals['_AUTHGATEWAYSERVICEREFRESHTOKENREQUEST']._serialized_start=324
  _globals['_AUTHGATEWAYSERVICEREFRESHTOKENREQUEST']._serialized_end=445
  _globals['_AUTHGATEWAYSERVICEREFRESHTOKENRESPONSE']._serialized_start=447
  _globals['_AUTHGATEWAYSERVICEREFRESHTOKENRESPONSE']._serialized_end=572
  _globals['_AUTHGATEWAYSERVICELOGOUTREQUEST']._serialized_start=574
  _globals['_AUTHGATEWAYSERVICELOGOUTREQUEST']._serialized_end=653
  _globals['_AUTHGATEWAYSERVICELOGOUTRESPONSE']._serialized_start=655
  _globals['_AUTHGATEWAYSERVICELOGOUTRESPONSE']._serialized_end=755
  _globals['_AUTHGATEWAYSERVICE']._serialized_start=758
  _globals['_AUTHGATEWAYSERVICE']._serialized_end=1157
# @@protoc_insertion_point(module_scope)
