# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: workflow/v2/workflow_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'workflow/v2/workflow_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.common.v2 import common_pb2 as common_dot_v2_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from spounge.workflow.v2 import workflow_pb2 as workflow_dot_v2_dot_workflow__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"workflow/v2/workflow_service.proto\x12\x0bworkflow.v2\x1a\x16\x63ommon/v2/common.proto\x1a google/protobuf/field_mask.proto\x1a\x1aworkflow/v2/workflow.proto\"\x93\x01\n\x15\x43reateWorkflowRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12/\n\x05steps\x18\x03 \x03(\x0b\x32\x19.workflow.v2.WorkflowStepR\x05stepsB\x0e\n\x0c_description\"Q\n\x16\x43reateWorkflowResponse\x12\x37\n\x08workflow\x18\x01 \x01(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08workflow\"`\n\x12GetWorkflowRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12\x1d\n\x07version\x18\x02 \x01(\x05H\x00R\x07version\x88\x01\x01\x42\n\n\x08_version\"N\n\x13GetWorkflowResponse\x12\x37\n\x08workflow\x18\x01 \x01(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08workflow\"\xf1\x01\n\x15UpdateWorkflowRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12;\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12%\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12/\n\x05steps\x18\x05 \x03(\x0b\x32\x19.workflow.v2.WorkflowStepR\x05stepsB\x0e\n\x0c_description\"Q\n\x16UpdateWorkflowResponse\x12\x37\n\x08workflow\x18\x01 \x01(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08workflow\"8\n\x15\x44\x65leteWorkflowRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\"C\n\x16\x44\x65leteWorkflowResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\"S\n\x14ListWorkflowsRequest\x12;\n\npagination\x18\x01 \x01(\x0b\x32\x1b.common.v2.PaginationParamsR\npagination\"\x8f\x01\n\x15ListWorkflowsResponse\x12\x39\n\tworkflows\x18\x01 \x03(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\tworkflows\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.common.v2.PaginationResultR\npagination\">\n\x1bListWorkflowVersionsRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\"W\n\x1cListWorkflowVersionsResponse\x12\x37\n\x08versions\x18\x01 \x03(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x08versions2\xc5\x04\n\x0fWorkflowService\x12[\n\x0e\x43reateWorkflow\x12\".workflow.v2.CreateWorkflowRequest\x1a#.workflow.v2.CreateWorkflowResponse\"\x00\x12R\n\x0bGetWorkflow\x12\x1f.workflow.v2.GetWorkflowRequest\x1a .workflow.v2.GetWorkflowResponse\"\x00\x12[\n\x0eUpdateWorkflow\x12\".workflow.v2.UpdateWorkflowRequest\x1a#.workflow.v2.UpdateWorkflowResponse\"\x00\x12[\n\x0e\x44\x65leteWorkflow\x12\".workflow.v2.DeleteWorkflowRequest\x1a#.workflow.v2.DeleteWorkflowResponse\"\x00\x12X\n\rListWorkflows\x12!.workflow.v2.ListWorkflowsRequest\x1a\".workflow.v2.ListWorkflowsResponse\"\x00\x12m\n\x14ListWorkflowVersions\x12(.workflow.v2.ListWorkflowVersionsRequest\x1a).workflow.v2.ListWorkflowVersionsResponse\"\x00\x42\xb8\x01\n\x0f\x63om.workflow.v2B\x14WorkflowServiceProtoP\x01ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\xa2\x02\x03WXX\xaa\x02\x0bWorkflow.V2\xca\x02\x0bWorkflow\\V2\xe2\x02\x17Workflow\\V2\\GPBMetadata\xea\x02\x0cWorkflow::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workflow.v2.workflow_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.workflow.v2B\024WorkflowServiceProtoP\001ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\242\002\003WXX\252\002\013Workflow.V2\312\002\013Workflow\\V2\342\002\027Workflow\\V2\\GPBMetadata\352\002\014Workflow::V2'
  _globals['_CREATEWORKFLOWREQUEST']._serialized_start=138
  _globals['_CREATEWORKFLOWREQUEST']._serialized_end=285
  _globals['_CREATEWORKFLOWRESPONSE']._serialized_start=287
  _globals['_CREATEWORKFLOWRESPONSE']._serialized_end=368
  _globals['_GETWORKFLOWREQUEST']._serialized_start=370
  _globals['_GETWORKFLOWREQUEST']._serialized_end=466
  _globals['_GETWORKFLOWRESPONSE']._serialized_start=468
  _globals['_GETWORKFLOWRESPONSE']._serialized_end=546
  _globals['_UPDATEWORKFLOWREQUEST']._serialized_start=549
  _globals['_UPDATEWORKFLOWREQUEST']._serialized_end=790
  _globals['_UPDATEWORKFLOWRESPONSE']._serialized_start=792
  _globals['_UPDATEWORKFLOWRESPONSE']._serialized_end=873
  _globals['_DELETEWORKFLOWREQUEST']._serialized_start=875
  _globals['_DELETEWORKFLOWREQUEST']._serialized_end=931
  _globals['_DELETEWORKFLOWRESPONSE']._serialized_start=933
  _globals['_DELETEWORKFLOWRESPONSE']._serialized_end=1000
  _globals['_LISTWORKFLOWSREQUEST']._serialized_start=1002
  _globals['_LISTWORKFLOWSREQUEST']._serialized_end=1085
  _globals['_LISTWORKFLOWSRESPONSE']._serialized_start=1088
  _globals['_LISTWORKFLOWSRESPONSE']._serialized_end=1231
  _globals['_LISTWORKFLOWVERSIONSREQUEST']._serialized_start=1233
  _globals['_LISTWORKFLOWVERSIONSREQUEST']._serialized_end=1295
  _globals['_LISTWORKFLOWVERSIONSRESPONSE']._serialized_start=1297
  _globals['_LISTWORKFLOWVERSIONSRESPONSE']._serialized_end=1384
  _globals['_WORKFLOWSERVICE']._serialized_start=1387
  _globals['_WORKFLOWSERVICE']._serialized_end=1968
# @@protoc_insertion_point(module_scope)
