# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/user_gateway_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'api/v2/user_gateway_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spounge.user.v2 import user_service_pb2 as user_dot_v2_dot_user__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!api/v2/user_gateway_service.proto\x12\x06\x61pi.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1auser/v2/user_service.proto\"W\n\'UserGatewayServiceGetUserProfileRequest\x12,\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x05\x65mpty\"\x86\x01\n(UserGatewayServiceGetUserProfileResponse\x12Z\n\x19get_user_profile_response\x18\x01 \x01(\x0b\x32\x1f.user.v2.GetUserProfileResponseR\x16getUserProfileResponse\"\x8e\x01\n*UserGatewayServiceUpdateUserProfileRequest\x12`\n\x1bupdate_user_profile_request\x18\x01 \x01(\x0b\x32!.user.v2.UpdateUserProfileRequestR\x18updateUserProfileRequest\"\x92\x01\n+UserGatewayServiceUpdateUserProfileResponse\x12\x63\n\x1cupdate_user_profile_response\x18\x01 \x01(\x0b\x32\".user.v2.UpdateUserProfileResponseR\x19updateUserProfileResponse2\xc0\x02\n\x12UserGatewayService\x12\x8d\x01\n\x0eGetUserProfile\x12/.api.v2.UserGatewayServiceGetUserProfileRequest\x1a\x30.api.v2.UserGatewayServiceGetUserProfileResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v2/user/profile\x12\x99\x01\n\x11UpdateUserProfile\x12\x32.api.v2.UserGatewayServiceUpdateUserProfileRequest\x1a\x33.api.v2.UserGatewayServiceUpdateUserProfileResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x32\x10/v2/user/profile:\x01*B\x98\x01\n\ncom.api.v2B\x17UserGatewayServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v2.user_gateway_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.api.v2B\027UserGatewayServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2'
  _globals['_USERGATEWAYSERVICE'].methods_by_name['GetUserProfile']._loaded_options = None
  _globals['_USERGATEWAYSERVICE'].methods_by_name['GetUserProfile']._serialized_options = b'\202\323\344\223\002\022\022\020/v2/user/profile'
  _globals['_USERGATEWAYSERVICE'].methods_by_name['UpdateUserProfile']._loaded_options = None
  _globals['_USERGATEWAYSERVICE'].methods_by_name['UpdateUserProfile']._serialized_options = b'\202\323\344\223\002\0252\020/v2/user/profile:\001*'
  _globals['_USERGATEWAYSERVICEGETUSERPROFILEREQUEST']._serialized_start=132
  _globals['_USERGATEWAYSERVICEGETUSERPROFILEREQUEST']._serialized_end=219
  _globals['_USERGATEWAYSERVICEGETUSERPROFILERESPONSE']._serialized_start=222
  _globals['_USERGATEWAYSERVICEGETUSERPROFILERESPONSE']._serialized_end=356
  _globals['_USERGATEWAYSERVICEUPDATEUSERPROFILEREQUEST']._serialized_start=359
  _globals['_USERGATEWAYSERVICEUPDATEUSERPROFILEREQUEST']._serialized_end=501
  _globals['_USERGATEWAYSERVICEUPDATEUSERPROFILERESPONSE']._serialized_start=504
  _globals['_USERGATEWAYSERVICEUPDATEUSERPROFILERESPONSE']._serialized_end=650
  _globals['_USERGATEWAYSERVICE']._serialized_start=653
  _globals['_USERGATEWAYSERVICE']._serialized_end=973
# @@protoc_insertion_point(module_scope)
