# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/nodes/v1/autonomous.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/nodes/v1/autonomous.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from spounge.nodus.v1.common.v1 import types_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_types__pb2
from spounge.nodus.v1.integrations.v1 import llm_pb2 as nodus_dot_v1_dot_integrations_dot_v1_dot_llm__pb2
from spounge.nodus.v1.mcp.v1 import tool_pb2 as nodus_dot_v1_dot_mcp_dot_v1_dot_tool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"nodus/v1/nodes/v1/autonomous.proto\x12\x11nodus.v1.nodes.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1enodus/v1/common/v1/types.proto\x1a\"nodus/v1/integrations/v1/llm.proto\x1a\x1anodus/v1/mcp/v1/tool.proto\"\xef\x06\n\x14\x41utonomousNodeConfig\x12I\n\nllm_config\x18\x01 \x01(\x0b\x32*.nodus.v1.integrations.v1.LLMConfigurationR\tllmConfig\x12;\n\nagent_type\x18\x03 \x01(\x0e\x32\x1c.nodus.v1.nodes.v1.AgentTypeR\tagentType\x12\x1c\n\tobjective\x18\x04 \x01(\tR\tobjective\x12%\n\x0esystem_context\x18\x05 \x01(\tR\rsystemContext\x12J\n\x10initial_messages\x18\x06 \x03(\x0b\x32\x1f.nodus.v1.common.v1.ChatMessageR\x0finitialMessages\x12\x39\n\ntool_scope\x18\x07 \x01(\x0b\x32\x1a.nodus.v1.mcp.v1.ToolScopeR\ttoolScope\x12M\n\rtool_strategy\x18\x08 \x01(\x0e\x32(.nodus.v1.nodes.v1.ToolSelectionStrategyR\x0ctoolStrategy\x12%\n\x0emax_iterations\x18\t \x01(\x05R\rmaxIterations\x12G\n\x12max_execution_time\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationR\x10maxExecutionTime\x12\x31\n\x14\x63onfidence_threshold\x18\x0b \x01(\x02R\x13\x63onfidenceThreshold\x12#\n\rpersist_state\x18\x0c \x01(\x08R\x0cpersistState\x12\x1b\n\tstate_key\x18\r \x01(\tR\x08stateKey\x12\x36\n\tstate_ttl\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x08stateTtl\x12)\n\x10\x65nable_streaming\x18\x0f \x01(\x08R\x0f\x65nableStreaming\x12,\n\x12stream_interval_ms\x18\x10 \x01(\x05R\x10streamIntervalMs\x12>\n\x07options\x18\x11 \x01(\x0b\x32$.nodus.v1.nodes.v1.AutonomousOptionsR\x07options\"\xcf\x03\n\x11\x41utonomousOptions\x12\x34\n\x16\x65nable_self_reflection\x18\x01 \x01(\x08R\x14\x65nableSelfReflection\x12/\n\x13reflection_interval\x18\x02 \x01(\x05R\x12reflectionInterval\x12>\n\x1b\x65nable_memory_consolidation\x18\x03 \x01(\x08R\x19\x65nableMemoryConsolidation\x12:\n\x19\x65nable_goal_decomposition\x18\x04 \x01(\x08R\x17\x65nableGoalDecomposition\x12)\n\x10\x65xploration_rate\x18\x05 \x01(\x02R\x0f\x65xplorationRate\x12g\n\x11\x63ustom_parameters\x18\x06 \x03(\x0b\x32:.nodus.v1.nodes.v1.AutonomousOptions.CustomParametersEntryR\x10\x63ustomParameters\x1a\x43\n\x15\x43ustomParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xaf\x01\n\tAgentType\x12\x1a\n\x16\x41GENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41GENT_TYPE_REACT\x10\x01\x12\x1f\n\x1b\x41GENT_TYPE_CHAIN_OF_THOUGHT\x10\x02\x12\x1b\n\x17\x41GENT_TYPE_TOOL_CALLING\x10\x03\x12\x17\n\x13\x41GENT_TYPE_PLANNING\x10\x04\x12\x19\n\x15\x41GENT_TYPE_REFLECTION\x10\x05*\xdb\x01\n\x15ToolSelectionStrategy\x12\'\n#TOOL_SELECTION_STRATEGY_UNSPECIFIED\x10\x00\x12%\n!TOOL_SELECTION_STRATEGY_AUTOMATIC\x10\x01\x12$\n TOOL_SELECTION_STRATEGY_EXPLICIT\x10\x02\x12\'\n#TOOL_SELECTION_STRATEGY_INTERACTIVE\x10\x03\x12#\n\x1fTOOL_SELECTION_STRATEGY_LEARNED\x10\x04\x42\xd6\x01\n\x15\x63om.nodus.v1.nodes.v1B\x0f\x41utonomousProtoP\x01ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\xa2\x02\x03NVN\xaa\x02\x11Nodus.V1.Nodes.V1\xca\x02\x11Nodus\\V1\\Nodes\\V1\xe2\x02\x1dNodus\\V1\\Nodes\\V1\\GPBMetadata\xea\x02\x14Nodus::V1::Nodes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.nodes.v1.autonomous_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.nodus.v1.nodes.v1B\017AutonomousProtoP\001ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\242\002\003NVN\252\002\021Nodus.V1.Nodes.V1\312\002\021Nodus\\V1\\Nodes\\V1\342\002\035Nodus\\V1\\Nodes\\V1\\GPBMetadata\352\002\024Nodus::V1::Nodes::V1'
  _globals['_AUTONOMOUSOPTIONS_CUSTOMPARAMETERSENTRY']._loaded_options = None
  _globals['_AUTONOMOUSOPTIONS_CUSTOMPARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_AGENTTYPE']._serialized_start=1534
  _globals['_AGENTTYPE']._serialized_end=1709
  _globals['_TOOLSELECTIONSTRATEGY']._serialized_start=1712
  _globals['_TOOLSELECTIONSTRATEGY']._serialized_end=1931
  _globals['_AUTONOMOUSNODECONFIG']._serialized_start=186
  _globals['_AUTONOMOUSNODECONFIG']._serialized_end=1065
  _globals['_AUTONOMOUSOPTIONS']._serialized_start=1068
  _globals['_AUTONOMOUSOPTIONS']._serialized_end=1531
  _globals['_AUTONOMOUSOPTIONS_CUSTOMPARAMETERSENTRY']._serialized_start=1464
  _globals['_AUTONOMOUSOPTIONS_CUSTOMPARAMETERSENTRY']._serialized_end=1531
# @@protoc_insertion_point(module_scope)
