# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/nodes/v1/reasoning.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/nodes/v1/reasoning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from spounge.nodus.v1.common.v1 import types_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_types__pb2
from spounge.nodus.v1.integrations.v1 import llm_pb2 as nodus_dot_v1_dot_integrations_dot_v1_dot_llm__pb2
from spounge.nodus.v1.mcp.v1 import tool_pb2 as nodus_dot_v1_dot_mcp_dot_v1_dot_tool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nodus/v1/nodes/v1/reasoning.proto\x12\x11nodus.v1.nodes.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1enodus/v1/common/v1/types.proto\x1a\"nodus/v1/integrations/v1/llm.proto\x1a\x1anodus/v1/mcp/v1/tool.proto\"\x88\x05\n\x13ReasoningNodeConfig\x12I\n\nllm_config\x18\x01 \x01(\x0b\x32*.nodus.v1.integrations.v1.LLMConfigurationR\tllmConfig\x12R\n\x10model_parameters\x18\x03 \x01(\x0b\x32\'.nodus.v1.integrations.v1.LLMParametersR\x0fmodelParameters\x12#\n\rsystem_prompt\x18\x04 \x01(\tR\x0csystemPrompt\x12\x1f\n\x0buser_prompt\x18\x05 \x01(\tR\nuserPrompt\x12R\n\x14\x63onversation_history\x18\x06 \x03(\x0b\x32\x1f.nodus.v1.common.v1.ChatMessageR\x13\x63onversationHistory\x12\x39\n\ntool_scope\x18\x07 \x01(\x0b\x32\x1a.nodus.v1.mcp.v1.ToolScopeR\ttoolScope\x12#\n\rallowed_tools\x18\x08 \x03(\tR\x0c\x61llowedTools\x12\'\n\x0f\x66orbidden_tools\x18\t \x03(\tR\x0e\x66orbiddenTools\x12\x46\n\x11reasoning_timeout\x18\x0b \x01(\x0b\x32\x19.google.protobuf.DurationR\x10reasoningTimeout\x12(\n\x10require_tool_use\x18\x0c \x01(\x08R\x0erequireToolUse\x12=\n\x07options\x18\r \x01(\x0b\x32#.nodus.v1.nodes.v1.ReasoningOptionsR\x07options\"\xda\x02\n\x10ReasoningOptions\x12\x35\n\x17\x65nable_chain_of_thought\x18\x01 \x01(\x08R\x14\x65nableChainOfThought\x12\x36\n\x17include_reasoning_trace\x18\x02 \x01(\x08R\x15includeReasoningTrace\x12\x31\n\x14temperature_override\x18\x03 \x01(\x02R\x13temperatureOverride\x12\x32\n\x15validate_tool_outputs\x18\x04 \x01(\x08R\x13validateToolOutputs\x12:\n\x19output_format_instruction\x18\x05 \x01(\tR\x17outputFormatInstruction\x12\x34\n\x16required_output_fields\x18\x06 \x03(\tR\x14requiredOutputFieldsB\xd5\x01\n\x15\x63om.nodus.v1.nodes.v1B\x0eReasoningProtoP\x01ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\xa2\x02\x03NVN\xaa\x02\x11Nodus.V1.Nodes.V1\xca\x02\x11Nodus\\V1\\Nodes\\V1\xe2\x02\x1dNodus\\V1\\Nodes\\V1\\GPBMetadata\xea\x02\x14Nodus::V1::Nodes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.nodes.v1.reasoning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.nodus.v1.nodes.v1B\016ReasoningProtoP\001ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\242\002\003NVN\252\002\021Nodus.V1.Nodes.V1\312\002\021Nodus\\V1\\Nodes\\V1\342\002\035Nodus\\V1\\Nodes\\V1\\GPBMetadata\352\002\024Nodus::V1::Nodes::V1'
  _globals['_REASONINGNODECONFIG']._serialized_start=185
  _globals['_REASONINGNODECONFIG']._serialized_end=833
  _globals['_REASONINGOPTIONS']._serialized_start=836
  _globals['_REASONINGOPTIONS']._serialized_end=1182
# @@protoc_insertion_point(module_scope)
