# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/common/v1/types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/common/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enodus/v1/common/v1/types.proto\x12\x12nodus.v1.common.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb7\x02\n\x10\x45xecutionContext\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x1f\n\x0bworkflow_id\x18\x02 \x01(\tR\nworkflowId\x12\x17\n\x07user_id\x18\x03 \x01(\tR\x06userId\x12N\n\x08metadata\x18\x04 \x03(\x0b\x32\x32.nodus.v1.common.v1.ExecutionContext.MetadataEntryR\x08metadata\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x9e\x02\n\x0b\x43hatMessage\x12\x33\n\x04role\x18\x01 \x01(\x0e\x32\x1f.nodus.v1.common.v1.MessageRoleR\x04role\x12\x18\n\x07\x63ontent\x18\x02 \x01(\tR\x07\x63ontent\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12I\n\x08metadata\x18\x04 \x03(\x0b\x32-.nodus.v1.common.v1.ChatMessage.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\x85\x01\n\x08NodeType\x12\x19\n\x15NODE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10NODE_TYPE_DIRECT\x10\x01\x12\x17\n\x13NODE_TYPE_REASONING\x10\x02\x12\x18\n\x14NODE_TYPE_AUTONOMOUS\x10\x03\x12\x15\n\x11NODE_TYPE_WEBHOOK\x10\x04*\xea\x01\n\x0f\x45xecutionStatus\x12 \n\x1c\x45XECUTION_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45XECUTION_STATUS_PENDING\x10\x01\x12\x1c\n\x18\x45XECUTION_STATUS_RUNNING\x10\x02\x12\x1e\n\x1a\x45XECUTION_STATUS_COMPLETED\x10\x03\x12\x1b\n\x17\x45XECUTION_STATUS_FAILED\x10\x04\x12\x1c\n\x18\x45XECUTION_STATUS_TIMEOUT\x10\x05\x12\x1e\n\x1a\x45XECUTION_STATUS_CANCELLED\x10\x06*z\n\x0cResultFormat\x12\x1d\n\x19RESULT_FORMAT_UNSPECIFIED\x10\x00\x12\x15\n\x11RESULT_FORMAT_RAW\x10\x01\x12\x16\n\x12RESULT_FORMAT_JSON\x10\x02\x12\x1c\n\x18RESULT_FORMAT_STRUCTURED\x10\x03*\x8e\x01\n\x0bMessageRole\x12\x1c\n\x18MESSAGE_ROLE_UNSPECIFIED\x10\x00\x12\x17\n\x13MESSAGE_ROLE_SYSTEM\x10\x01\x12\x15\n\x11MESSAGE_ROLE_USER\x10\x02\x12\x1a\n\x16MESSAGE_ROLE_ASSISTANT\x10\x03\x12\x15\n\x11MESSAGE_ROLE_TOOL\x10\x04\x42\xd8\x01\n\x16\x63om.nodus.v1.common.v1B\nTypesProtoP\x01ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\xa2\x02\x03NVC\xaa\x02\x12Nodus.V1.Common.V1\xca\x02\x12Nodus\\V1\\Common\\V1\xe2\x02\x1eNodus\\V1\\Common\\V1\\GPBMetadata\xea\x02\x15Nodus::V1::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.common.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.nodus.v1.common.v1B\nTypesProtoP\001ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\242\002\003NVC\252\002\022Nodus.V1.Common.V1\312\002\022Nodus\\V1\\Common\\V1\342\002\036Nodus\\V1\\Common\\V1\\GPBMetadata\352\002\025Nodus::V1::Common::V1'
  _globals['_EXECUTIONCONTEXT_METADATAENTRY']._loaded_options = None
  _globals['_EXECUTIONCONTEXT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CHATMESSAGE_METADATAENTRY']._loaded_options = None
  _globals['_CHATMESSAGE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_NODETYPE']._serialized_start=691
  _globals['_NODETYPE']._serialized_end=824
  _globals['_EXECUTIONSTATUS']._serialized_start=827
  _globals['_EXECUTIONSTATUS']._serialized_end=1061
  _globals['_RESULTFORMAT']._serialized_start=1063
  _globals['_RESULTFORMAT']._serialized_end=1185
  _globals['_MESSAGEROLE']._serialized_start=1188
  _globals['_MESSAGEROLE']._serialized_end=1330
  _globals['_EXECUTIONCONTEXT']._serialized_start=88
  _globals['_EXECUTIONCONTEXT']._serialized_end=399
  _globals['_EXECUTIONCONTEXT_METADATAENTRY']._serialized_start=340
  _globals['_EXECUTIONCONTEXT_METADATAENTRY']._serialized_end=399
  _globals['_CHATMESSAGE']._serialized_start=402
  _globals['_CHATMESSAGE']._serialized_end=688
  _globals['_CHATMESSAGE_METADATAENTRY']._serialized_start=340
  _globals['_CHATMESSAGE_METADATAENTRY']._serialized_end=399
# @@protoc_insertion_point(module_scope)
