# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/integrations/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/integrations/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from spounge.nodus.v1.common.v1 import auth_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"nodus/v1/integrations/v1/api.proto\x12\x18nodus.v1.integrations.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dnodus/v1/common/v1/auth.proto\"\x8e\x04\n\tAPIConfig\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x19\n\x08\x62\x61se_url\x18\x02 \x01(\tR\x07\x62\x61seUrl\x12I\n\x0b\x61uth_config\x18\x04 \x01(\x0b\x32(.nodus.v1.common.v1.AuthenticationConfigR\nauthConfig\x12`\n\x0f\x64\x65\x66\x61ult_headers\x18\x05 \x03(\x0b\x32\x37.nodus.v1.integrations.v1.APIConfig.DefaultHeadersEntryR\x0e\x64\x65\x66\x61ultHeaders\x12\x33\n\x07timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12O\n\x0cretry_config\x18\x07 \x01(\x0b\x32,.nodus.v1.integrations.v1.RetryConfigurationR\x0bretryConfig\x12\\\n\x11rate_limit_config\x18\x08 \x01(\x0b\x32\x30.nodus.v1.integrations.v1.RateLimitConfigurationR\x0frateLimitConfig\x1a\x41\n\x13\x44\x65\x66\x61ultHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x9c\x02\n\x12RetryConfiguration\x12!\n\x0cmax_attempts\x18\x01 \x01(\x05R\x0bmaxAttempts\x12\x42\n\x0finitial_backoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0einitialBackoff\x12:\n\x0bmax_backoff\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\nmaxBackoff\x12-\n\x12\x62\x61\x63koff_multiplier\x18\x04 \x01(\x02R\x11\x62\x61\x63koffMultiplier\x12\x34\n\x16retryable_status_codes\x18\x05 \x03(\x05R\x14retryableStatusCodes\"\xa9\x01\n\x16RateLimitConfiguration\x12.\n\x13requests_per_second\x18\x01 \x01(\x05R\x11requestsPerSecond\x12.\n\x13requests_per_minute\x18\x02 \x01(\x05R\x11requestsPerMinute\x12/\n\x13\x63oncurrent_requests\x18\x03 \x01(\x05R\x12\x63oncurrentRequests\"\x8f\x03\n\x0bHTTPRequest\x12<\n\x06method\x18\x01 \x01(\x0e\x32$.nodus.v1.integrations.v1.HTTPMethodR\x06method\x12\x1a\n\x08\x65ndpoint\x18\x02 \x01(\tR\x08\x65ndpoint\x12L\n\x07headers\x18\x03 \x03(\x0b\x32\x32.nodus.v1.integrations.v1.HTTPRequest.HeadersEntryR\x07headers\x12:\n\x0cquery_params\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x0bqueryParams\x12+\n\x04\x62ody\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x62ody\x12\x33\n\x07timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa7\x02\n\x0cHTTPResponse\x12\x1f\n\x0bstatus_code\x18\x01 \x01(\x05R\nstatusCode\x12M\n\x07headers\x18\x02 \x03(\x0b\x32\x33.nodus.v1.integrations.v1.HTTPResponse.HeadersEntryR\x07headers\x12+\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x62ody\x12>\n\rresponse_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0cresponseTime\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xc7\x01\n\nHTTPMethod\x12\x1b\n\x17HTTP_METHOD_UNSPECIFIED\x10\x00\x12\x13\n\x0fHTTP_METHOD_GET\x10\x01\x12\x14\n\x10HTTP_METHOD_POST\x10\x02\x12\x13\n\x0fHTTP_METHOD_PUT\x10\x03\x12\x16\n\x12HTTP_METHOD_DELETE\x10\x04\x12\x15\n\x11HTTP_METHOD_PATCH\x10\x05\x12\x14\n\x10HTTP_METHOD_HEAD\x10\x06\x12\x17\n\x13HTTP_METHOD_OPTIONS\x10\x07\x42\x80\x02\n\x1c\x63om.nodus.v1.integrations.v1B\x08\x41piProtoP\x01ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\xa2\x02\x03NVI\xaa\x02\x18Nodus.V1.Integrations.V1\xca\x02\x18Nodus\\V1\\Integrations\\V1\xe2\x02$Nodus\\V1\\Integrations\\V1\\GPBMetadata\xea\x02\x1bNodus::V1::Integrations::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.integrations.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.nodus.v1.integrations.v1B\010ApiProtoP\001ZSgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/integrations/v1;integrationsv1\242\002\003NVI\252\002\030Nodus.V1.Integrations.V1\312\002\030Nodus\\V1\\Integrations\\V1\342\002$Nodus\\V1\\Integrations\\V1\\GPBMetadata\352\002\033Nodus::V1::Integrations::V1'
  _globals['_APICONFIG_DEFAULTHEADERSENTRY']._loaded_options = None
  _globals['_APICONFIG_DEFAULTHEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPRESPONSE_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPRESPONSE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPMETHOD']._serialized_start=1846
  _globals['_HTTPMETHOD']._serialized_end=2045
  _globals['_APICONFIG']._serialized_start=158
  _globals['_APICONFIG']._serialized_end=684
  _globals['_APICONFIG_DEFAULTHEADERSENTRY']._serialized_start=619
  _globals['_APICONFIG_DEFAULTHEADERSENTRY']._serialized_end=684
  _globals['_RETRYCONFIGURATION']._serialized_start=687
  _globals['_RETRYCONFIGURATION']._serialized_end=971
  _globals['_RATELIMITCONFIGURATION']._serialized_start=974
  _globals['_RATELIMITCONFIGURATION']._serialized_end=1143
  _globals['_HTTPREQUEST']._serialized_start=1146
  _globals['_HTTPREQUEST']._serialized_end=1545
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_start=1487
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_end=1545
  _globals['_HTTPRESPONSE']._serialized_start=1548
  _globals['_HTTPRESPONSE']._serialized_end=1843
  _globals['_HTTPRESPONSE_HEADERSENTRY']._serialized_start=1487
  _globals['_HTTPRESPONSE_HEADERSENTRY']._serialized_end=1545
# @@protoc_insertion_point(module_scope)
