# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/common/v1/auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/common/v1/auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dnodus/v1/common/v1/auth.proto\x12\x12nodus.v1.common.v1\"\x89\x04\n\x14\x41uthenticationConfig\x12\x39\n\tauth_type\x18\x01 \x01(\x0e\x32\x1c.nodus.v1.common.v1.AuthTypeR\x08\x61uthType\x12\x33\n\x15\x61pi_key_credential_id\x18\x02 \x01(\tH\x00R\x12\x61piKeyCredentialId\x12=\n\x1a\x62\x65\x61rer_token_credential_id\x18\x03 \x01(\tH\x00R\x17\x62\x65\x61rerTokenCredentialId\x12\x44\n\nbasic_auth\x18\x04 \x01(\x0b\x32#.nodus.v1.common.v1.BasicAuthConfigH\x00R\tbasicAuth\x12:\n\x06oauth2\x18\x05 \x01(\x0b\x32 .nodus.v1.common.v1.OAuth2ConfigH\x00R\x06oauth2\x12l\n\x12\x63ustom_auth_params\x18\x06 \x03(\x0b\x32>.nodus.v1.common.v1.AuthenticationConfig.CustomAuthParamsEntryR\x10\x63ustomAuthParams\x1a\x43\n\x15\x43ustomAuthParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\r\n\x0b\x63redentials\"c\n\x0f\x42\x61sicAuthConfig\x12\x1a\n\x08username\x18\x01 \x01(\tR\x08username\x12\x34\n\x16password_credential_id\x18\x02 \x01(\tR\x14passwordCredentialId\"\xb9\x01\n\x0cOAuth2Config\x12\x1b\n\ttoken_url\x18\x01 \x01(\tR\x08tokenUrl\x12\x35\n\x17\x63lient_id_credential_id\x18\x02 \x01(\tR\x14\x63lientIdCredentialId\x12=\n\x1b\x63lient_secret_credential_id\x18\x03 \x01(\tR\x18\x63lientSecretCredentialId\x12\x16\n\x06scopes\x18\x04 \x03(\tR\x06scopes*\xad\x01\n\x08\x41uthType\x12\x19\n\x15\x41UTH_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41UTH_TYPE_NONE\x10\x01\x12\x15\n\x11\x41UTH_TYPE_API_KEY\x10\x02\x12\x1a\n\x16\x41UTH_TYPE_BEARER_TOKEN\x10\x03\x12\x13\n\x0f\x41UTH_TYPE_BASIC\x10\x04\x12\x14\n\x10\x41UTH_TYPE_OAUTH2\x10\x05\x12\x14\n\x10\x41UTH_TYPE_CUSTOM\x10\x06\x42\xd7\x01\n\x16\x63om.nodus.v1.common.v1B\tAuthProtoP\x01ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\xa2\x02\x03NVC\xaa\x02\x12Nodus.V1.Common.V1\xca\x02\x12Nodus\\V1\\Common\\V1\xe2\x02\x1eNodus\\V1\\Common\\V1\\GPBMetadata\xea\x02\x15Nodus::V1::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.common.v1.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.nodus.v1.common.v1B\tAuthProtoP\001ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\242\002\003NVC\252\002\022Nodus.V1.Common.V1\312\002\022Nodus\\V1\\Common\\V1\342\002\036Nodus\\V1\\Common\\V1\\GPBMetadata\352\002\025Nodus::V1::Common::V1'
  _globals['_AUTHENTICATIONCONFIG_CUSTOMAUTHPARAMSENTRY']._loaded_options = None
  _globals['_AUTHENTICATIONCONFIG_CUSTOMAUTHPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_AUTHTYPE']._serialized_start=867
  _globals['_AUTHTYPE']._serialized_end=1040
  _globals['_AUTHENTICATIONCONFIG']._serialized_start=54
  _globals['_AUTHENTICATIONCONFIG']._serialized_end=575
  _globals['_AUTHENTICATIONCONFIG_CUSTOMAUTHPARAMSENTRY']._serialized_start=493
  _globals['_AUTHENTICATIONCONFIG_CUSTOMAUTHPARAMSENTRY']._serialized_end=560
  _globals['_BASICAUTHCONFIG']._serialized_start=577
  _globals['_BASICAUTHCONFIG']._serialized_end=676
  _globals['_OAUTH2CONFIG']._serialized_start=679
  _globals['_OAUTH2CONFIG']._serialized_end=864
# @@protoc_insertion_point(module_scope)
