# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iam/v2/api_key.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'iam/v2/api_key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14iam/v2/api_key.proto\x12\x06iam.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xaa\x02\n\x06\x41PIKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x1d\n\nkey_prefix\x18\x04 \x01(\tR\tkeyPrefix\x12%\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x41\n\x0clast_used_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\nlastUsedAt\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x0f\n\r_last_used_at\"Z\n\x10\x41PIKeyWithSecret\x12\'\n\x07\x61pi_key\x18\x01 \x01(\x0b\x32\x0e.iam.v2.APIKeyR\x06\x61piKey\x12\x1d\n\nsecret_key\x18\x02 \x01(\tR\tsecretKeyB\x8c\x01\n\ncom.iam.v2B\x0b\x41piKeyProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/iam/v2;iamv2\xa2\x02\x03IXX\xaa\x02\x06Iam.V2\xca\x02\x06Iam\\V2\xe2\x02\x12Iam\\V2\\GPBMetadata\xea\x02\x07Iam::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iam.v2.api_key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.iam.v2B\013ApiKeyProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/iam/v2;iamv2\242\002\003IXX\252\002\006Iam.V2\312\002\006Iam\\V2\342\002\022Iam\\V2\\GPBMetadata\352\002\007Iam::V2'
  _globals['_APIKEY']._serialized_start=66
  _globals['_APIKEY']._serialized_end=364
  _globals['_APIKEYWITHSECRET']._serialized_start=366
  _globals['_APIKEYWITHSECRET']._serialized_end=456
# @@protoc_insertion_point(module_scope)
