# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iam/v2/managed_secret.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'iam/v2/managed_secret.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1biam/v2/managed_secret.proto\x12\x06iam.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xfc\x02\n\rManagedSecret\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12-\n\x04type\x18\x04 \x01(\x0e\x32\x19.iam.v2.ManagedSecretTypeR\x04type\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x42\n\x0f\x63ollection_data\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x0e\x63ollectionData\x12\x36\n\titem_data\x18\x08 \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x08itemDataB\r\n\x0bsecret_data*\x9a\x01\n\x11ManagedSecretType\x12#\n\x1fMANAGED_SECRET_TYPE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aMANAGED_SECRET_TYPE_CUSTOM\x10\x01\x12\x1c\n\x18MANAGED_SECRET_TYPE_ITEM\x10\x02\x12\"\n\x1eMANAGED_SECRET_TYPE_COLLECTION\x10\x03\x42\x93\x01\n\ncom.iam.v2B\x12ManagedSecretProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/iam/v2;iamv2\xa2\x02\x03IXX\xaa\x02\x06Iam.V2\xca\x02\x06Iam\\V2\xe2\x02\x12Iam\\V2\\GPBMetadata\xea\x02\x07Iam::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iam.v2.managed_secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.iam.v2B\022ManagedSecretProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/iam/v2;iamv2\242\002\003IXX\252\002\006Iam.V2\312\002\006Iam\\V2\342\002\022Iam\\V2\\GPBMetadata\352\002\007Iam::V2'
  _globals['_MANAGEDSECRETTYPE']._serialized_start=486
  _globals['_MANAGEDSECRETTYPE']._serialized_end=640
  _globals['_MANAGEDSECRET']._serialized_start=103
  _globals['_MANAGEDSECRET']._serialized_end=483
# @@protoc_insertion_point(module_scope)
