# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/rpc/error_details.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/rpc/error_details.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egoogle/rpc/error_details.proto\x12\ngoogle.rpc\x1a\x1egoogle/protobuf/duration.proto\"\xb9\x01\n\tErrorInfo\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12?\n\x08metadata\x18\x03 \x03(\x0b\x32#.google.rpc.ErrorInfo.MetadataEntryR\x08metadata\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"G\n\tRetryInfo\x12:\n\x0bretry_delay\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\nretryDelay\"H\n\tDebugInfo\x12#\n\rstack_entries\x18\x01 \x03(\tR\x0cstackEntries\x12\x16\n\x06\x64\x65tail\x18\x02 \x01(\tR\x06\x64\x65tail\"\x8e\x04\n\x0cQuotaFailure\x12\x42\n\nviolations\x18\x01 \x03(\x0b\x32\".google.rpc.QuotaFailure.ViolationR\nviolations\x1a\xb9\x03\n\tViolation\x12\x18\n\x07subject\x18\x01 \x01(\tR\x07subject\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1f\n\x0b\x61pi_service\x18\x03 \x01(\tR\napiService\x12!\n\x0cquota_metric\x18\x04 \x01(\tR\x0bquotaMetric\x12\x19\n\x08quota_id\x18\x05 \x01(\tR\x07quotaId\x12\x62\n\x10quota_dimensions\x18\x06 \x03(\x0b\x32\x37.google.rpc.QuotaFailure.Violation.QuotaDimensionsEntryR\x0fquotaDimensions\x12\x1f\n\x0bquota_value\x18\x07 \x01(\x03R\nquotaValue\x12\x31\n\x12\x66uture_quota_value\x18\x08 \x01(\x03H\x00R\x10\x66utureQuotaValue\x88\x01\x01\x1a\x42\n\x14QuotaDimensionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x15\n\x13_future_quota_value\"\xbd\x01\n\x13PreconditionFailure\x12I\n\nviolations\x18\x01 \x03(\x0b\x32).google.rpc.PreconditionFailure.ViolationR\nviolations\x1a[\n\tViolation\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x18\n\x07subject\x18\x02 \x01(\tR\x07subject\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\"\x8c\x02\n\nBadRequest\x12P\n\x10\x66ield_violations\x18\x01 \x03(\x0b\x32%.google.rpc.BadRequest.FieldViolationR\x0f\x66ieldViolations\x1a\xab\x01\n\x0e\x46ieldViolation\x12\x14\n\x05\x66ield\x18\x01 \x01(\tR\x05\x66ield\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06reason\x18\x03 \x01(\tR\x06reason\x12I\n\x11localized_message\x18\x04 \x01(\x0b\x32\x1c.google.rpc.LocalizedMessageR\x10localizedMessage\"O\n\x0bRequestInfo\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12!\n\x0cserving_data\x18\x02 \x01(\tR\x0bservingData\"\x90\x01\n\x0cResourceInfo\x12#\n\rresource_type\x18\x01 \x01(\tR\x0cresourceType\x12#\n\rresource_name\x18\x02 \x01(\tR\x0cresourceName\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\"o\n\x04Help\x12+\n\x05links\x18\x01 \x03(\x0b\x32\x15.google.rpc.Help.LinkR\x05links\x1a:\n\x04Link\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\"D\n\x10LocalizedMessage\x12\x16\n\x06locale\x18\x01 \x01(\tR\x06locale\x12\x18\n\x07message\x18\x02 \x01(\tR\x07messageB\xad\x01\n\x0e\x63om.google.rpcB\x11\x45rrorDetailsProtoP\x01Z?google.golang.org/genproto/googleapis/rpc/errdetails;errdetails\xa2\x02\x03GRX\xaa\x02\nGoogle.Rpc\xca\x02\nGoogle\\Rpc\xe2\x02\x16Google\\Rpc\\GPBMetadata\xea\x02\x0bGoogle::Rpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.rpc.error_details_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.rpcB\021ErrorDetailsProtoP\001Z?google.golang.org/genproto/googleapis/rpc/errdetails;errdetails\242\002\003GRX\252\002\nGoogle.Rpc\312\002\nGoogle\\Rpc\342\002\026Google\\Rpc\\GPBMetadata\352\002\013Google::Rpc'
  _globals['_ERRORINFO_METADATAENTRY']._loaded_options = None
  _globals['_ERRORINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY']._loaded_options = None
  _globals['_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY']._serialized_options = b'8\001'
  _globals['_ERRORINFO']._serialized_start=79
  _globals['_ERRORINFO']._serialized_end=264
  _globals['_ERRORINFO_METADATAENTRY']._serialized_start=205
  _globals['_ERRORINFO_METADATAENTRY']._serialized_end=264
  _globals['_RETRYINFO']._serialized_start=266
  _globals['_RETRYINFO']._serialized_end=337
  _globals['_DEBUGINFO']._serialized_start=339
  _globals['_DEBUGINFO']._serialized_end=411
  _globals['_QUOTAFAILURE']._serialized_start=414
  _globals['_QUOTAFAILURE']._serialized_end=940
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_start=499
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_end=940
  _globals['_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY']._serialized_start=851
  _globals['_QUOTAFAILURE_VIOLATION_QUOTADIMENSIONSENTRY']._serialized_end=917
  _globals['_PRECONDITIONFAILURE']._serialized_start=943
  _globals['_PRECONDITIONFAILURE']._serialized_end=1132
  _globals['_PRECONDITIONFAILURE_VIOLATION']._serialized_start=1041
  _globals['_PRECONDITIONFAILURE_VIOLATION']._serialized_end=1132
  _globals['_BADREQUEST']._serialized_start=1135
  _globals['_BADREQUEST']._serialized_end=1403
  _globals['_BADREQUEST_FIELDVIOLATION']._serialized_start=1232
  _globals['_BADREQUEST_FIELDVIOLATION']._serialized_end=1403
  _globals['_REQUESTINFO']._serialized_start=1405
  _globals['_REQUESTINFO']._serialized_end=1484
  _globals['_RESOURCEINFO']._serialized_start=1487
  _globals['_RESOURCEINFO']._serialized_end=1631
  _globals['_HELP']._serialized_start=1633
  _globals['_HELP']._serialized_end=1744
  _globals['_HELP_LINK']._serialized_start=1686
  _globals['_HELP_LINK']._serialized_end=1744
  _globals['_LOCALIZEDMESSAGE']._serialized_start=1746
  _globals['_LOCALIZEDMESSAGE']._serialized_end=1814
# @@protoc_insertion_point(module_scope)
