# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/nodes/v1/webhook.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/nodes/v1/webhook.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fnodus/v1/nodes/v1/webhook.proto\x12\x11nodus.v1.nodes.v1\x1a\x1egoogle/protobuf/duration.proto\"\x9f\x01\n\x11WebhookNodeConfig\x12\x1b\n\tlisten_id\x18\x01 \x01(\tR\x08listenId\x12\x33\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07timeout\x12\x38\n\x18verification_config_name\x18\x03 \x01(\tR\x16verificationConfigNameB\xd3\x01\n\x15\x63om.nodus.v1.nodes.v1B\x0cWebhookProtoP\x01ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\xa2\x02\x03NVN\xaa\x02\x11Nodus.V1.Nodes.V1\xca\x02\x11Nodus\\V1\\Nodes\\V1\xe2\x02\x1dNodus\\V1\\Nodes\\V1\\GPBMetadata\xea\x02\x14Nodus::V1::Nodes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.nodes.v1.webhook_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.nodus.v1.nodes.v1B\014WebhookProtoP\001ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\242\002\003NVN\252\002\021Nodus.V1.Nodes.V1\312\002\021Nodus\\V1\\Nodes\\V1\342\002\035Nodus\\V1\\Nodes\\V1\\GPBMetadata\352\002\024Nodus::V1::Nodes::V1'
  _globals['_WEBHOOKNODECONFIG']._serialized_start=87
  _globals['_WEBHOOKNODECONFIG']._serialized_end=246
# @@protoc_insertion_point(module_scope)
