# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/mcp/v1/tool.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/mcp/v1/tool.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spounge.nodus.v1.common.v1 import resources_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_resources__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1anodus/v1/mcp/v1/tool.proto\x12\x0fnodus.v1.mcp.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\"nodus/v1/common/v1/resources.proto\"\xe7\x03\n\x07MCPTool\x12\x17\n\x07tool_id\x18\x01 \x01(\tR\x06toolId\x12\x1b\n\tserver_id\x18\x02 \x01(\tR\x08serverId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12:\n\x0cinput_schema\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x0binputSchema\x12<\n\routput_schema\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructR\x0coutputSchema\x12\x39\n\x08\x63\x61tegory\x18\x07 \x01(\x0e\x32\x1d.nodus.v1.mcp.v1.ToolCategoryR\x08\x63\x61tegory\x12\x12\n\x04tags\x18\x08 \x03(\tR\x04tags\x12]\n\x15resource_requirements\x18\t \x01(\x0b\x32(.nodus.v1.common.v1.ResourceRequirementsR\x14resourceRequirements\x12H\n\rconfiguration\x18\n \x01(\x0b\x32\".nodus.v1.mcp.v1.ToolConfigurationR\rconfiguration\"\xb5\x03\n\x11ToolConfiguration\x12\x33\n\x15requires_confirmation\x18\x01 \x01(\x08R\x14requiresConfirmation\x12-\n\x12supports_streaming\x18\x02 \x01(\x08R\x11supportsStreaming\x12\x31\n\x14required_permissions\x18\x03 \x03(\tR\x13requiredPermissions\x12h\n\x12\x64\x65\x66\x61ult_parameters\x18\x04 \x03(\x0b\x32\x39.nodus.v1.mcp.v1.ToolConfiguration.DefaultParametersEntryR\x11\x64\x65\x66\x61ultParameters\x12Y\n\x15parameter_constraints\x18\x05 \x03(\x0b\x32$.nodus.v1.mcp.v1.ParameterConstraintR\x14parameterConstraints\x1a\x44\n\x16\x44\x65\x66\x61ultParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xee\x01\n\x13ParameterConstraint\x12%\n\x0eparameter_name\x18\x01 \x01(\tR\rparameterName\x12H\n\x0f\x63onstraint_type\x18\x02 \x01(\x0e\x32\x1f.nodus.v1.mcp.v1.ConstraintTypeR\x0e\x63onstraintType\x12\x41\n\x10\x63onstraint_value\x18\x03 \x01(\x0b\x32\x16.google.protobuf.ValueR\x0f\x63onstraintValue\x12#\n\rerror_message\x18\x04 \x01(\tR\x0c\x65rrorMessage\"\xc5\x01\n\tToolScope\x12\x1d\n\nserver_ids\x18\x01 \x03(\tR\tserverIds\x12=\n\ncategories\x18\x02 \x03(\x0e\x32\x1d.nodus.v1.mcp.v1.ToolCategoryR\ncategories\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\x12\x46\n\raccess_policy\x18\x04 \x01(\x0b\x32!.nodus.v1.mcp.v1.ToolAccessPolicyR\x0c\x61\x63\x63\x65ssPolicy\"\xd6\x02\n\x10ToolAccessPolicy\x12\x31\n\x14require_confirmation\x18\x01 \x01(\x08R\x13requireConfirmation\x12\x33\n\x15restricted_operations\x18\x02 \x03(\tR\x14restrictedOperations\x12j\n\x13parameter_overrides\x18\x03 \x03(\x0b\x32\x39.nodus.v1.mcp.v1.ToolAccessPolicy.ParameterOverridesEntryR\x12parameterOverrides\x12\'\n\x0f\x61llowed_domains\x18\x04 \x03(\tR\x0e\x61llowedDomains\x1a\x45\n\x17ParameterOverridesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xc0\x02\n\x0cToolCategory\x12\x1d\n\x19TOOL_CATEGORY_UNSPECIFIED\x10\x00\x12\x1d\n\x19TOOL_CATEGORY_DATA_ACCESS\x10\x01\x12\x1d\n\x19TOOL_CATEGORY_COMPUTATION\x10\x02\x12\x1f\n\x1bTOOL_CATEGORY_COMMUNICATION\x10\x03\x12\x1d\n\x19TOOL_CATEGORY_FILE_SYSTEM\x10\x04\x12\x1d\n\x19TOOL_CATEGORY_WEB_BROWSER\x10\x05\x12\x1c\n\x18TOOL_CATEGORY_API_CLIENT\x10\x06\x12\x1a\n\x16TOOL_CATEGORY_ANALYSIS\x10\x07\x12\x1a\n\x16TOOL_CATEGORY_DATABASE\x10\x08\x12\x1e\n\x1aTOOL_CATEGORY_ML_INFERENCE\x10\t*\xe1\x01\n\x0e\x43onstraintType\x12\x1f\n\x1b\x43ONSTRAINT_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x43ONSTRAINT_TYPE_REQUIRED\x10\x01\x12\x1e\n\x1a\x43ONSTRAINT_TYPE_MIN_LENGTH\x10\x02\x12\x1e\n\x1a\x43ONSTRAINT_TYPE_MAX_LENGTH\x10\x03\x12\x1b\n\x17\x43ONSTRAINT_TYPE_PATTERN\x10\x04\x12\x18\n\x14\x43ONSTRAINT_TYPE_ENUM\x10\x05\x12\x19\n\x15\x43ONSTRAINT_TYPE_RANGE\x10\x06\x42\xc2\x01\n\x13\x63om.nodus.v1.mcp.v1B\tToolProtoP\x01ZAgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/mcp/v1;mcpv1\xa2\x02\x03NVM\xaa\x02\x0fNodus.V1.Mcp.V1\xca\x02\x0fNodus\\V1\\Mcp\\V1\xe2\x02\x1bNodus\\V1\\Mcp\\V1\\GPBMetadata\xea\x02\x12Nodus::V1::Mcp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.mcp.v1.tool_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.nodus.v1.mcp.v1B\tToolProtoP\001ZAgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/mcp/v1;mcpv1\242\002\003NVM\252\002\017Nodus.V1.Mcp.V1\312\002\017Nodus\\V1\\Mcp\\V1\342\002\033Nodus\\V1\\Mcp\\V1\\GPBMetadata\352\002\022Nodus::V1::Mcp::V1'
  _globals['_TOOLCONFIGURATION_DEFAULTPARAMETERSENTRY']._loaded_options = None
  _globals['_TOOLCONFIGURATION_DEFAULTPARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_TOOLACCESSPOLICY_PARAMETEROVERRIDESENTRY']._loaded_options = None
  _globals['_TOOLACCESSPOLICY_PARAMETEROVERRIDESENTRY']._serialized_options = b'8\001'
  _globals['_TOOLCATEGORY']._serialized_start=1830
  _globals['_TOOLCATEGORY']._serialized_end=2150
  _globals['_CONSTRAINTTYPE']._serialized_start=2153
  _globals['_CONSTRAINTTYPE']._serialized_end=2378
  _globals['_MCPTOOL']._serialized_start=114
  _globals['_MCPTOOL']._serialized_end=601
  _globals['_TOOLCONFIGURATION']._serialized_start=604
  _globals['_TOOLCONFIGURATION']._serialized_end=1041
  _globals['_TOOLCONFIGURATION_DEFAULTPARAMETERSENTRY']._serialized_start=973
  _globals['_TOOLCONFIGURATION_DEFAULTPARAMETERSENTRY']._serialized_end=1041
  _globals['_PARAMETERCONSTRAINT']._serialized_start=1044
  _globals['_PARAMETERCONSTRAINT']._serialized_end=1282
  _globals['_TOOLSCOPE']._serialized_start=1285
  _globals['_TOOLSCOPE']._serialized_end=1482
  _globals['_TOOLACCESSPOLICY']._serialized_start=1485
  _globals['_TOOLACCESSPOLICY']._serialized_end=1827
  _globals['_TOOLACCESSPOLICY_PARAMETEROVERRIDESENTRY']._serialized_start=1758
  _globals['_TOOLACCESSPOLICY_PARAMETEROVERRIDESENTRY']._serialized_end=1827
# @@protoc_insertion_point(module_scope)
