# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: workflow/v2/execution.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'workflow/v2/execution.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.common.v2 import common_pb2 as common_dot_v2_dot_common__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bworkflow/v2/execution.proto\x12\x0bworkflow.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb9\x04\n\x11WorkflowExecution\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x1f\n\x0bworkflow_id\x18\x03 \x01(\tR\nworkflowId\x12)\n\x10workflow_version\x18\x04 \x01(\x05R\x0fworkflowVersion\x12\x34\n\x06status\x18\x05 \x01(\x0e\x32\x1c.workflow.v2.ExecutionStatusR\x06status\x12\x31\n\x07\x63ontext\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructR\x07\x63ontext\x12/\n\x06output\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructR\x06output\x12,\n\x05\x65rror\x18\x08 \x01(\x0b\x32\x11.common.v2.StatusH\x00R\x05\x65rror\x88\x01\x01\x12\x39\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12>\n\nstarted_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\tstartedAt\x88\x01\x01\x12\x42\n\x0c\x63ompleted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\x0b\x63ompletedAt\x88\x01\x01\x42\x08\n\x06_errorB\r\n\x0b_started_atB\x0f\n\r_completed_at\"\x85\x02\n\x17WorkflowExecutionUpdate\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32\x1c.workflow.v2.ExecutionStatusR\x06status\x12<\n\rcontext_delta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x0c\x63ontextDelta\x12\x38\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x19\n\x08is_final\x18\x05 \x01(\x08R\x07isFinal*\xcc\x01\n\x0f\x45xecutionStatus\x12 \n\x1c\x45XECUTION_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45XECUTION_STATUS_PENDING\x10\x01\x12\x1c\n\x18\x45XECUTION_STATUS_RUNNING\x10\x02\x12\x1e\n\x1a\x45XECUTION_STATUS_COMPLETED\x10\x03\x12\x1b\n\x17\x45XECUTION_STATUS_FAILED\x10\x04\x12\x1e\n\x1a\x45XECUTION_STATUS_CANCELLED\x10\x05\x42\xb2\x01\n\x0f\x63om.workflow.v2B\x0e\x45xecutionProtoP\x01ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\xa2\x02\x03WXX\xaa\x02\x0bWorkflow.V2\xca\x02\x0bWorkflow\\V2\xe2\x02\x17Workflow\\V2\\GPBMetadata\xea\x02\x0cWorkflow::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workflow.v2.execution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.workflow.v2B\016ExecutionProtoP\001ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\242\002\003WXX\252\002\013Workflow.V2\312\002\013Workflow\\V2\342\002\027Workflow\\V2\\GPBMetadata\352\002\014Workflow::V2'
  _globals['_EXECUTIONSTATUS']._serialized_start=968
  _globals['_EXECUTIONSTATUS']._serialized_end=1172
  _globals['_WORKFLOWEXECUTION']._serialized_start=132
  _globals['_WORKFLOWEXECUTION']._serialized_end=701
  _globals['_WORKFLOWEXECUTIONUPDATE']._serialized_start=704
  _globals['_WORKFLOWEXECUTIONUPDATE']._serialized_end=965
# @@protoc_insertion_point(module_scope)
