# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/dashboard_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'api/v2/dashboard_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spounge.iam.v2 import api_key_pb2 as iam_dot_v2_dot_api__key__pb2
from spounge.iam.v2 import managed_secret_pb2 as iam_dot_v2_dot_managed__secret__pb2
from spounge.user.v2 import user_pb2 as user_dot_v2_dot_user__pb2
from spounge.workflow.v2 import execution_pb2 as workflow_dot_v2_dot_execution__pb2
from spounge.workflow.v2 import workflow_pb2 as workflow_dot_v2_dot_workflow__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61pi/v2/dashboard_service.proto\x12\x06\x61pi.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x14iam/v2/api_key.proto\x1a\x1biam/v2/managed_secret.proto\x1a\x12user/v2/user.proto\x1a\x1bworkflow/v2/execution.proto\x1a\x1aworkflow/v2/workflow.proto\"\x15\n\x13GetDashboardRequest\"\xcf\x02\n\x14GetDashboardResponse\x12\x37\n\x0cuser_profile\x18\x01 \x01(\x0b\x32\x14.user.v2.UserProfileR\x0buserProfile\x12\x46\n\x10recent_workflows\x18\x02 \x03(\x0b\x32\x1b.workflow.v2.WorkflowConfigR\x0frecentWorkflows\x12K\n\x11recent_executions\x18\x03 \x03(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\x10recentExecutions\x12)\n\x08\x61pi_keys\x18\x04 \x03(\x0b\x32\x0e.iam.v2.APIKeyR\x07\x61piKeys\x12>\n\x0fmanaged_secrets\x18\x05 \x03(\x0b\x32\x15.iam.v2.ManagedSecretR\x0emanagedSecrets2t\n\x10\x44\x61shboardService\x12`\n\x0cGetDashboard\x12\x1b.api.v2.GetDashboardRequest\x1a\x1c.api.v2.GetDashboardResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v2/dashboardB\x96\x01\n\ncom.api.v2B\x15\x44\x61shboardServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api.v2.dashboard_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\ncom.api.v2B\025DashboardServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2'
  _globals['_DASHBOARDSERVICE'].methods_by_name['GetDashboard']._loaded_options = None
  _globals['_DASHBOARDSERVICE'].methods_by_name['GetDashboard']._serialized_options = b'\202\323\344\223\002\017\022\r/v2/dashboard'
  _globals['_GETDASHBOARDREQUEST']._serialized_start=200
  _globals['_GETDASHBOARDREQUEST']._serialized_end=221
  _globals['_GETDASHBOARDRESPONSE']._serialized_start=224
  _globals['_GETDASHBOARDRESPONSE']._serialized_end=559
  _globals['_DASHBOARDSERVICE']._serialized_start=561
  _globals['_DASHBOARDSERVICE']._serialized_end=677
# @@protoc_insertion_point(module_scope)
