# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: auth/v2/token.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'auth/v2/token.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61uth/v2/token.proto\x12\x07\x61uth.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe0\x01\n\tAuthToken\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12#\n\rrefresh_token\x18\x02 \x01(\tR\x0crefreshToken\x12\x39\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12\x31\n\ntoken_type\x18\x04 \x01(\x0e\x32\x12.auth.v2.TokenTypeR\ttokenType\x12\x1d\n\nsession_id\x18\x05 \x01(\tR\tsessionId*>\n\tTokenType\x12\x1a\n\x16TOKEN_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11TOKEN_TYPE_BEARER\x10\x01\x42\x92\x01\n\x0b\x63om.auth.v2B\nTokenProtoP\x01Z:github.com/spounge-ai/spounge-protos/gen/go/auth/v2;authv2\xa2\x02\x03\x41XX\xaa\x02\x07\x41uth.V2\xca\x02\x07\x41uth\\V2\xe2\x02\x13\x41uth\\V2\\GPBMetadata\xea\x02\x08\x41uth::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth.v2.token_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013com.auth.v2B\nTokenProtoP\001Z:github.com/spounge-ai/spounge-protos/gen/go/auth/v2;authv2\242\002\003AXX\252\002\007Auth.V2\312\002\007Auth\\V2\342\002\023Auth\\V2\\GPBMetadata\352\002\010Auth::V2'
  _globals['_TOKENTYPE']._serialized_start=292
  _globals['_TOKENTYPE']._serialized_end=354
  _globals['_AUTHTOKEN']._serialized_start=66
  _globals['_AUTHTOKEN']._serialized_end=290
# @@protoc_insertion_point(module_scope)
