# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/key_types.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/key_types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1apolykey/v2/key_types.proto\x12\npolykey.v2*\x7f\n\x07KeyType\x12\x18\n\x14KEY_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10KEY_TYPE_API_KEY\x10\x01\x12\x14\n\x10KEY_TYPE_AES_256\x10\x02\x12\x15\n\x11KEY_TYPE_RSA_4096\x10\x03\x12\x17\n\x13KEY_TYPE_ECDSA_P384\x10\x04*\x8a\x01\n\tKeyStatus\x12\x1a\n\x16KEY_STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11KEY_STATUS_ACTIVE\x10\x01\x12\x17\n\x13KEY_STATUS_ROTATING\x10\x02\x12\x19\n\x15KEY_STATUS_DEPRECATED\x10\x03\x12\x16\n\x12KEY_STATUS_REVOKED\x10\x04*\x8f\x01\n\x10RotationStrategy\x12!\n\x1dROTATION_STRATEGY_UNSPECIFIED\x10\x00\x12\x19\n\x15ROTATION_STRATEGY_HOT\x10\x01\x12\x1c\n\x18ROTATION_STRATEGY_STAGED\x10\x02\x12\x1f\n\x1bROTATION_STRATEGY_SCHEDULED\x10\x03\x42\xaa\x01\n\x0e\x63om.polykey.v2B\rKeyTypesProtoP\x01Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.key_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\rKeyTypesProtoP\001Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_KEYTYPE']._serialized_start=42
  _globals['_KEYTYPE']._serialized_end=169
  _globals['_KEYSTATUS']._serialized_start=172
  _globals['_KEYSTATUS']._serialized_end=310
  _globals['_ROTATIONSTRATEGY']._serialized_start=313
  _globals['_ROTATIONSTRATEGY']._serialized_end=456
# @@protoc_insertion_point(module_scope)
