# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/common/v1/resources.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/common/v1/resources.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"nodus/v1/common/v1/resources.proto\x12\x12nodus.v1.common.v1\x1a\x1egoogle/protobuf/duration.proto\"\x98\x02\n\x0eResourceLimits\x12:\n\x19max_concurrent_executions\x18\x01 \x01(\x05R\x17maxConcurrentExecutions\x12G\n\x12max_execution_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10maxExecutionTime\x12(\n\x10max_memory_bytes\x18\x03 \x01(\x03R\x0emaxMemoryBytes\x12$\n\x0emax_tool_calls\x18\x04 \x01(\x05R\x0cmaxToolCalls\x12\x31\n\x15max_output_size_bytes\x18\x05 \x01(\x03R\x12maxOutputSizeBytes\"\xa2\x02\n\x13ResourceConsumption\x12*\n\x11memory_used_bytes\x18\x01 \x01(\x03R\x0fmemoryUsedBytes\x12\x36\n\x17\x63pu_utilization_percent\x18\x02 \x01(\x02R\x15\x63puUtilizationPercent\x12)\n\x10network_requests\x18\x03 \x01(\x05R\x0fnetworkRequests\x12:\n\x19network_bytes_transferred\x18\x04 \x01(\x03R\x17networkBytesTransferred\x12@\n\x0etotal_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\rtotalDuration\"\xf3\x01\n\x14ResourceRequirements\x12\x34\n\x16\x65stimated_memory_bytes\x18\x01 \x01(\x03R\x14\x65stimatedMemoryBytes\x12H\n\x12\x65stimated_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11\x65stimatedDuration\x12\x36\n\x17\x65stimated_network_calls\x18\x03 \x01(\x05R\x15\x65stimatedNetworkCalls\x12#\n\rresource_tier\x18\x04 \x01(\tR\x0cresourceTierB\xdc\x01\n\x16\x63om.nodus.v1.common.v1B\x0eResourcesProtoP\x01ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\xa2\x02\x03NVC\xaa\x02\x12Nodus.V1.Common.V1\xca\x02\x12Nodus\\V1\\Common\\V1\xe2\x02\x1eNodus\\V1\\Common\\V1\\GPBMetadata\xea\x02\x15Nodus::V1::Common::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.common.v1.resources_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.nodus.v1.common.v1B\016ResourcesProtoP\001ZGgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/common/v1;commonv1\242\002\003NVC\252\002\022Nodus.V1.Common.V1\312\002\022Nodus\\V1\\Common\\V1\342\002\036Nodus\\V1\\Common\\V1\\GPBMetadata\352\002\025Nodus::V1::Common::V1'
  _globals['_RESOURCELIMITS']._serialized_start=91
  _globals['_RESOURCELIMITS']._serialized_end=371
  _globals['_RESOURCECONSUMPTION']._serialized_start=374
  _globals['_RESOURCECONSUMPTION']._serialized_end=664
  _globals['_RESOURCEREQUIREMENTS']._serialized_start=667
  _globals['_RESOURCEREQUIREMENTS']._serialized_end=910
# @@protoc_insertion_point(module_scope)
