# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/nodes/v1/direct.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/nodes/v1/direct.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from spounge.nodus.v1.common.v1 import types_pb2 as nodus_dot_v1_dot_common_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enodus/v1/nodes/v1/direct.proto\x12\x11nodus.v1.nodes.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1enodus/v1/common/v1/types.proto\"\xb2\x03\n\x10\x44irectNodeConfig\x12\"\n\rmcp_server_id\x18\x01 \x01(\tR\x0bmcpServerId\x12\x1b\n\ttool_name\x18\x03 \x01(\tR\x08toolName\x12@\n\x0ftool_parameters\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x0etoolParameters\x12<\n\x0ctool_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0btoolTimeout\x12/\n\x13validate_parameters\x18\x06 \x01(\x08R\x12validateParameters\x12\x45\n\routput_format\x18\x07 \x01(\x0e\x32 .nodus.v1.common.v1.ResultFormatR\x0coutputFormat\x12%\n\x0e\x65xtract_fields\x18\x08 \x03(\tR\rextractFields\x12>\n\x07options\x18\t \x01(\x0b\x32$.nodus.v1.nodes.v1.DirectNodeOptionsR\x07options\"\x9a\x03\n\x11\x44irectNodeOptions\x12!\n\x0c\x63\x61\x63he_result\x18\x01 \x01(\x08R\x0b\x63\x61\x63heResult\x12\x36\n\tcache_ttl\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08\x63\x61\x63heTtl\x12\x31\n\x14require_confirmation\x18\x03 \x01(\x08R\x13requireConfirmation\x12m\n\x13parameter_overrides\x18\x04 \x03(\x0b\x32<.nodus.v1.nodes.v1.DirectNodeOptions.ParameterOverridesEntryR\x12parameterOverrides\x12\x41\n\x0cretry_policy\x18\x05 \x01(\x0b\x32\x1e.nodus.v1.nodes.v1.RetryPolicyR\x0bretryPolicy\x1a\x45\n\x17ParameterOverridesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x93\x02\n\x0bRetryPolicy\x12!\n\x0cmax_attempts\x18\x01 \x01(\x05R\x0bmaxAttempts\x12\x42\n\x0finitial_backoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0einitialBackoff\x12:\n\x0bmax_backoff\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\nmaxBackoff\x12-\n\x12\x62\x61\x63koff_multiplier\x18\x04 \x01(\x02R\x11\x62\x61\x63koffMultiplier\x12\x32\n\x15retryable_error_codes\x18\x05 \x03(\tR\x13retryableErrorCodesB\xd2\x01\n\x15\x63om.nodus.v1.nodes.v1B\x0b\x44irectProtoP\x01ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\xa2\x02\x03NVN\xaa\x02\x11Nodus.V1.Nodes.V1\xca\x02\x11Nodus\\V1\\Nodes\\V1\xe2\x02\x1dNodus\\V1\\Nodes\\V1\\GPBMetadata\xea\x02\x14Nodus::V1::Nodes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.nodes.v1.direct_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.nodus.v1.nodes.v1B\013DirectProtoP\001ZEgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/nodes/v1;nodesv1\242\002\003NVN\252\002\021Nodus.V1.Nodes.V1\312\002\021Nodus\\V1\\Nodes\\V1\342\002\035Nodus\\V1\\Nodes\\V1\\GPBMetadata\352\002\024Nodus::V1::Nodes::V1'
  _globals['_DIRECTNODEOPTIONS_PARAMETEROVERRIDESENTRY']._loaded_options = None
  _globals['_DIRECTNODEOPTIONS_PARAMETEROVERRIDESENTRY']._serialized_options = b'8\001'
  _globals['_DIRECTNODECONFIG']._serialized_start=148
  _globals['_DIRECTNODECONFIG']._serialized_end=582
  _globals['_DIRECTNODEOPTIONS']._serialized_start=585
  _globals['_DIRECTNODEOPTIONS']._serialized_end=995
  _globals['_DIRECTNODEOPTIONS_PARAMETEROVERRIDESENTRY']._serialized_start=926
  _globals['_DIRECTNODEOPTIONS_PARAMETEROVERRIDESENTRY']._serialized_end=995
  _globals['_RETRYPOLICY']._serialized_start=998
  _globals['_RETRYPOLICY']._serialized_end=1273
# @@protoc_insertion_point(module_scope)
