# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user/v2/user.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'user/v2/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12user/v2/user.proto\x12\x07user.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xef\x02\n\x0bUserProfile\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05\x65mail\x18\x02 \x01(\tR\x05\x65mail\x12\x1a\n\x08username\x18\x03 \x01(\tR\x08username\x12\"\n\nfirst_name\x18\x04 \x01(\tH\x00R\tfirstName\x88\x01\x01\x12 \n\tlast_name\x18\x05 \x01(\tH\x01R\x08lastName\x88\x01\x01\x12/\n\x11profile_image_url\x18\x06 \x01(\tH\x02R\x0fprofileImageUrl\x88\x01\x01\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAtB\r\n\x0b_first_nameB\x0c\n\n_last_nameB\x14\n\x12_profile_image_url\"b\n\x0f\x41\x63\x63ountSettings\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1a\n\x08timezone\x18\x02 \x01(\tR\x08timezone\x12\x1a\n\x08language\x18\x03 \x01(\tR\x08languageB\x91\x01\n\x0b\x63om.user.v2B\tUserProtoP\x01Z:github.com/spounge-ai/spounge-protos/gen/go/user/v2;userv2\xa2\x02\x03UXX\xaa\x02\x07User.V2\xca\x02\x07User\\V2\xe2\x02\x13User\\V2\\GPBMetadata\xea\x02\x08User::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user.v2.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013com.user.v2B\tUserProtoP\001Z:github.com/spounge-ai/spounge-protos/gen/go/user/v2;userv2\242\002\003UXX\252\002\007User.V2\312\002\007User\\V2\342\002\023User\\V2\\GPBMetadata\352\002\010User::V2'
  _globals['_USERPROFILE']._serialized_start=65
  _globals['_USERPROFILE']._serialized_end=432
  _globals['_ACCOUNTSETTINGS']._serialized_start=434
  _globals['_ACCOUNTSETTINGS']._serialized_end=532
# @@protoc_insertion_point(module_scope)
