# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spounge.polykey.v2 import common_pb2 as polykey_dot_v2_dot_common__pb2
from spounge.polykey.v2 import key_types_pb2 as polykey_dot_v2_dot_key__types__pb2
from spounge.polykey.v2 import metrics_pb2 as polykey_dot_v2_dot_metrics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18polykey/v2/service.proto\x12\npolykey.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x17polykey/v2/common.proto\x1a\x1apolykey/v2/key_types.proto\x1a\x18polykey/v2/metrics.proto\"\x85\x02\n\rGetKeyRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x03 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12\x18\n\x07version\x18\x04 \x01(\x05R\x07version\x12(\n\rskip_metadata\x18\x07 \x01(\x08H\x00R\x0cskipMetadata\x88\x01\x01\x42\x10\n\x0e_skip_metadata\"\x88\x02\n\x0eGetKeyResponse\x12:\n\x0ckey_material\x18\x01 \x01(\x0b\x32\x17.polykey.v2.KeyMaterialR\x0bkeyMaterial\x12\x33\n\x08metadata\x18\x02 \x01(\x0b\x32\x17.polykey.v2.KeyMetadataR\x08metadata\x12I\n\x12response_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12:\n\x19\x61uthorization_decision_id\x18\x04 \x01(\tR\x17\x61uthorizationDecisionId\"\xcc\x04\n\x0fListKeysRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x04 \x01(\tR\tpageToken\x12\x30\n\tkey_types\x18\x05 \x03(\x0e\x32\x13.polykey.v2.KeyTypeR\x08keyTypes\x12\x31\n\x08statuses\x18\x06 \x03(\x0e\x32\x15.polykey.v2.KeyStatusR\x08statuses\x12L\n\x0btag_filters\x18\x07 \x03(\x0b\x32+.polykey.v2.ListKeysRequest.TagFiltersEntryR\ntagFilters\x12?\n\rcreated_after\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x63reatedAfter\x12\x41\n\x0e\x63reated_before\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rcreatedBefore\x1a=\n\x0fTagFiltersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xfa\x01\n\x10ListKeysResponse\x12+\n\x04keys\x18\x01 \x03(\x0b\x32\x17.polykey.v2.KeyMetadataR\x04keys\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x05R\ntotalCount\x12I\n\x12response_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12%\n\x0e\x66iltered_count\x18\x05 \x01(\x05R\rfilteredCount\"\x94\x06\n\x10\x43reateKeyRequest\x12.\n\x08key_type\x18\x01 \x01(\x0e\x32\x13.polykey.v2.KeyTypeR\x07keyType\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12:\n\x04tags\x18\x04 \x03(\x0b\x32&.polykey.v2.CreateKeyRequest.TagsEntryR\x04tags\x12\x39\n\nexpires_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12>\n\x1binitial_authorized_contexts\x18\x06 \x03(\tR\x19initialAuthorizedContexts\x12Y\n\x0f\x61\x63\x63\x65ss_policies\x18\x07 \x03(\x0b\x32\x30.polykey.v2.CreateKeyRequest.AccessPoliciesEntryR\x0e\x61\x63\x63\x65ssPolicies\x12/\n\x13\x64\x61ta_classification\x18\x08 \x01(\tR\x12\x64\x61taClassification\x12_\n\x11generation_params\x18\t \x03(\x0b\x32\x32.polykey.v2.CreateKeyRequest.GenerationParamsEntryR\x10generationParams\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x41\n\x13\x41\x63\x63\x65ssPoliciesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15GenerationParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xe6\x01\n\x11\x43reateKeyResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x33\n\x08metadata\x18\x02 \x01(\x0b\x32\x17.polykey.v2.KeyMetadataR\x08metadata\x12:\n\x0ckey_material\x18\x03 \x01(\x0b\x32\x17.polykey.v2.KeyMaterialR\x0bkeyMaterial\x12I\n\x12response_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\"\xc0\x03\n\x10RotateKeyRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12\x38\n\x08strategy\x18\x03 \x01(\x0e\x32\x1c.polykey.v2.RotationStrategyR\x08strategy\x12\x30\n\x14grace_period_seconds\x18\x04 \x01(\x05R\x12gracePeriodSeconds\x12_\n\x11generation_params\x18\x05 \x03(\x0b\x32\x32.polykey.v2.RotateKeyRequest.GenerationParamsEntryR\x10generationParams\x12\x38\n\x18preserve_access_policies\x18\x06 \x01(\x08R\x16preserveAccessPolicies\x1a\x43\n\x15GenerationParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8a\x03\n\x11RotateKeyResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1f\n\x0bnew_version\x18\x02 \x01(\x05R\nnewVersion\x12)\n\x10previous_version\x18\x03 \x01(\x05R\x0fpreviousVersion\x12\x41\n\x10new_key_material\x18\x04 \x01(\x0b\x32\x17.polykey.v2.KeyMaterialR\x0enewKeyMaterial\x12\x33\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.polykey.v2.KeyMetadataR\x08metadata\x12I\n\x12rotation_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11rotationTimestamp\x12O\n\x16old_version_expires_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13oldVersionExpiresAt\"\xb6\x02\n\x10RevokeKeyRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12+\n\x11revocation_reason\x18\x03 \x01(\tR\x10revocationReason\x12\x1c\n\timmediate\x18\x04 \x01(\x08R\timmediate\x12=\n\x0c\x65\x66\x66\x65\x63tive_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65\x66\x66\x65\x63tiveAt\x12\x36\n\x17notify_external_systems\x18\x06 \x01(\x08R\x15notifyExternalSystems\"\x8e\x06\n\x18UpdateKeyMetadataRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12%\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12S\n\x0btags_to_add\x18\x04 \x03(\x0b\x32\x33.polykey.v2.UpdateKeyMetadataRequest.TagsToAddEntryR\ttagsToAdd\x12$\n\x0etags_to_remove\x18\x05 \x03(\tR\x0ctagsToRemove\x12&\n\x0f\x63ontexts_to_add\x18\x06 \x03(\tR\rcontextsToAdd\x12,\n\x12\x63ontexts_to_remove\x18\x07 \x03(\tR\x10\x63ontextsToRemove\x12h\n\x12policies_to_update\x18\x08 \x03(\x0b\x32:.polykey.v2.UpdateKeyMetadataRequest.PoliciesToUpdateEntryR\x10policiesToUpdate\x12>\n\nexpires_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\texpiresAt\x88\x01\x01\x12\x34\n\x13\x64\x61ta_classification\x18\n \x01(\tH\x02R\x12\x64\x61taClassification\x88\x01\x01\x1a<\n\x0eTagsToAddEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15PoliciesToUpdateEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\r\n\x0b_expires_atB\x16\n\x14_data_classification\"\xbd\x02\n\x15GetKeyMetadataRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x03 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12\x34\n\x16include_access_history\x18\x04 \x01(\x08R\x14includeAccessHistory\x12\x34\n\x16include_policy_details\x18\x05 \x01(\x08R\x14includePolicyDetails\x12\x18\n\x07version\x18\x06 \x01(\x05R\x07version\"\x99\x03\n\x16GetKeyMetadataResponse\x12\x33\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.polykey.v2.KeyMetadataR\x08metadata\x12\x45\n\x0e\x61\x63\x63\x65ss_history\x18\x02 \x03(\x0b\x32\x1e.polykey.v2.AccessHistoryEntryR\raccessHistory\x12\\\n\x0epolicy_details\x18\x03 \x03(\x0b\x32\x35.polykey.v2.GetKeyMetadataResponse.PolicyDetailsEntryR\rpolicyDetails\x12I\n\x12response_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x1aZ\n\x12PolicyDetailsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x18.polykey.v2.PolicyDetailR\x05value:\x02\x38\x01\x32\xe3\x04\n\x0ePolykeyService\x12?\n\x06GetKey\x12\x19.polykey.v2.GetKeyRequest\x1a\x1a.polykey.v2.GetKeyResponse\x12\x45\n\x08ListKeys\x12\x1b.polykey.v2.ListKeysRequest\x1a\x1c.polykey.v2.ListKeysResponse\x12H\n\tCreateKey\x12\x1c.polykey.v2.CreateKeyRequest\x1a\x1d.polykey.v2.CreateKeyResponse\x12H\n\tRotateKey\x12\x1c.polykey.v2.RotateKeyRequest\x1a\x1d.polykey.v2.RotateKeyResponse\x12\x41\n\tRevokeKey\x12\x1c.polykey.v2.RevokeKeyRequest\x1a\x16.google.protobuf.Empty\x12Q\n\x11UpdateKeyMetadata\x12$.polykey.v2.UpdateKeyMetadataRequest\x1a\x16.google.protobuf.Empty\x12W\n\x0eGetKeyMetadata\x12!.polykey.v2.GetKeyMetadataRequest\x1a\".polykey.v2.GetKeyMetadataResponse\x12\x46\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x1f.polykey.v2.HealthCheckResponseB\xa9\x01\n\x0e\x63om.polykey.v2B\x0cServiceProtoP\x01Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\014ServiceProtoP\001Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_LISTKEYSREQUEST_TAGFILTERSENTRY']._loaded_options = None
  _globals['_LISTKEYSREQUEST_TAGFILTERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEKEYREQUEST_TAGSENTRY']._loaded_options = None
  _globals['_CREATEKEYREQUEST_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEKEYREQUEST_ACCESSPOLICIESENTRY']._loaded_options = None
  _globals['_CREATEKEYREQUEST_ACCESSPOLICIESENTRY']._serialized_options = b'8\001'
  _globals['_CREATEKEYREQUEST_GENERATIONPARAMSENTRY']._loaded_options = None
  _globals['_CREATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_ROTATEKEYREQUEST_GENERATIONPARAMSENTRY']._loaded_options = None
  _globals['_ROTATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEKEYMETADATAREQUEST_TAGSTOADDENTRY']._loaded_options = None
  _globals['_UPDATEKEYMETADATAREQUEST_TAGSTOADDENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEKEYMETADATAREQUEST_POLICIESTOUPDATEENTRY']._loaded_options = None
  _globals['_UPDATEKEYMETADATAREQUEST_POLICIESTOUPDATEENTRY']._serialized_options = b'8\001'
  _globals['_GETKEYMETADATARESPONSE_POLICYDETAILSENTRY']._loaded_options = None
  _globals['_GETKEYMETADATARESPONSE_POLICYDETAILSENTRY']._serialized_options = b'8\001'
  _globals['_GETKEYREQUEST']._serialized_start=182
  _globals['_GETKEYREQUEST']._serialized_end=443
  _globals['_GETKEYRESPONSE']._serialized_start=446
  _globals['_GETKEYRESPONSE']._serialized_end=710
  _globals['_LISTKEYSREQUEST']._serialized_start=713
  _globals['_LISTKEYSREQUEST']._serialized_end=1301
  _globals['_LISTKEYSREQUEST_TAGFILTERSENTRY']._serialized_start=1240
  _globals['_LISTKEYSREQUEST_TAGFILTERSENTRY']._serialized_end=1301
  _globals['_LISTKEYSRESPONSE']._serialized_start=1304
  _globals['_LISTKEYSRESPONSE']._serialized_end=1554
  _globals['_CREATEKEYREQUEST']._serialized_start=1557
  _globals['_CREATEKEYREQUEST']._serialized_end=2345
  _globals['_CREATEKEYREQUEST_TAGSENTRY']._serialized_start=2154
  _globals['_CREATEKEYREQUEST_TAGSENTRY']._serialized_end=2209
  _globals['_CREATEKEYREQUEST_ACCESSPOLICIESENTRY']._serialized_start=2211
  _globals['_CREATEKEYREQUEST_ACCESSPOLICIESENTRY']._serialized_end=2276
  _globals['_CREATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_start=2278
  _globals['_CREATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_end=2345
  _globals['_CREATEKEYRESPONSE']._serialized_start=2348
  _globals['_CREATEKEYRESPONSE']._serialized_end=2578
  _globals['_ROTATEKEYREQUEST']._serialized_start=2581
  _globals['_ROTATEKEYREQUEST']._serialized_end=3029
  _globals['_ROTATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_start=2278
  _globals['_ROTATEKEYREQUEST_GENERATIONPARAMSENTRY']._serialized_end=2345
  _globals['_ROTATEKEYRESPONSE']._serialized_start=3032
  _globals['_ROTATEKEYRESPONSE']._serialized_end=3426
  _globals['_REVOKEKEYREQUEST']._serialized_start=3429
  _globals['_REVOKEKEYREQUEST']._serialized_end=3739
  _globals['_UPDATEKEYMETADATAREQUEST']._serialized_start=3742
  _globals['_UPDATEKEYMETADATAREQUEST']._serialized_end=4524
  _globals['_UPDATEKEYMETADATAREQUEST_TAGSTOADDENTRY']._serialized_start=4340
  _globals['_UPDATEKEYMETADATAREQUEST_TAGSTOADDENTRY']._serialized_end=4400
  _globals['_UPDATEKEYMETADATAREQUEST_POLICIESTOUPDATEENTRY']._serialized_start=4402
  _globals['_UPDATEKEYMETADATAREQUEST_POLICIESTOUPDATEENTRY']._serialized_end=4469
  _globals['_GETKEYMETADATAREQUEST']._serialized_start=4527
  _globals['_GETKEYMETADATAREQUEST']._serialized_end=4844
  _globals['_GETKEYMETADATARESPONSE']._serialized_start=4847
  _globals['_GETKEYMETADATARESPONSE']._serialized_end=5256
  _globals['_GETKEYMETADATARESPONSE_POLICYDETAILSENTRY']._serialized_start=5166
  _globals['_GETKEYMETADATARESPONSE_POLICYDETAILSENTRY']._serialized_end=5256
  _globals['_POLYKEYSERVICE']._serialized_start=5259
  _globals['_POLYKEYSERVICE']._serialized_end=5870
# @@protoc_insertion_point(module_scope)
