# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nodus/v1/service/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nodus/v1/service/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spounge.nodus.v1.nodes.v1 import execution_pb2 as nodus_dot_v1_dot_nodes_dot_v1_dot_execution__pb2
from spounge.nodus.v1.mcp.v1 import connection_pb2 as nodus_dot_v1_dot_mcp_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nodus/v1/service/v1/service.proto\x12\x13nodus.v1.service.v1\x1a\x1cgoogle/api/annotations.proto\x1a!nodus/v1/nodes/v1/execution.proto\x1a nodus/v1/mcp/v1/connection.proto\".\n\x12\x43heckHealthRequest\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\"\xda\x01\n\x13\x43heckHealthResponse\x12N\n\x06status\x18\x01 \x01(\x0e\x32\x36.nodus.v1.service.v1.CheckHealthResponse.ServingStatusR\x06status\"s\n\rServingStatus\x12&\n\"SERVING_STATUS_UNKNOWN_UNSPECIFIED\x10\x00\x12\x1a\n\x16SERVING_STATUS_SERVING\x10\x01\x12\x1e\n\x1aSERVING_STATUS_NOT_SERVING\x10\x02\x32\x9c\x06\n\x0cNodusService\x12z\n\x0b\x45xecuteNode\x12%.nodus.v1.nodes.v1.ExecuteNodeRequest\x1a&.nodus.v1.nodes.v1.ExecuteNodeResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/nodes:execute:\x01*\x12\x94\x01\n\x11\x45xecuteNodeStream\x12+.nodus.v1.nodes.v1.ExecuteNodeStreamRequest\x1a,.nodus.v1.nodes.v1.ExecuteNodeStreamResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/nodes:executeStream:\x01*0\x01\x12\x8f\x01\n\x11RegisterMCPServer\x12).nodus.v1.mcp.v1.RegisterMCPServerRequest\x1a*.nodus.v1.mcp.v1.RegisterMCPServerResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/mcp/servers:register:\x01*\x12z\n\x0eListMCPServers\x12&.nodus.v1.mcp.v1.ListMCPServersRequest\x1a\'.nodus.v1.mcp.v1.ListMCPServersResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/mcp/servers\x12u\n\rQueryMCPTools\x12%.nodus.v1.mcp.v1.QueryMCPToolsRequest\x1a&.nodus.v1.mcp.v1.QueryMCPToolsResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v1/mcp/tools\x12t\n\x0b\x43heckHealth\x12\'.nodus.v1.service.v1.CheckHealthRequest\x1a(.nodus.v1.service.v1.CheckHealthResponse\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/v1/healthB\xe1\x01\n\x17\x63om.nodus.v1.service.v1B\x0cServiceProtoP\x01ZIgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/service/v1;servicev1\xa2\x02\x03NVS\xaa\x02\x13Nodus.V1.Service.V1\xca\x02\x13Nodus\\V1\\Service\\V1\xe2\x02\x1fNodus\\V1\\Service\\V1\\GPBMetadata\xea\x02\x16Nodus::V1::Service::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nodus.v1.service.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.nodus.v1.service.v1B\014ServiceProtoP\001ZIgithub.com/spounge-ai/spounge-protos/gen/go/nodus/v1/service/v1;servicev1\242\002\003NVS\252\002\023Nodus.V1.Service.V1\312\002\023Nodus\\V1\\Service\\V1\342\002\037Nodus\\V1\\Service\\V1\\GPBMetadata\352\002\026Nodus::V1::Service::V1'
  _globals['_NODUSSERVICE'].methods_by_name['ExecuteNode']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['ExecuteNode']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/nodes:execute:\001*'
  _globals['_NODUSSERVICE'].methods_by_name['ExecuteNodeStream']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['ExecuteNodeStream']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/nodes:executeStream:\001*'
  _globals['_NODUSSERVICE'].methods_by_name['RegisterMCPServer']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['RegisterMCPServer']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/mcp/servers:register:\001*'
  _globals['_NODUSSERVICE'].methods_by_name['ListMCPServers']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['ListMCPServers']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/mcp/servers'
  _globals['_NODUSSERVICE'].methods_by_name['QueryMCPTools']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['QueryMCPTools']._serialized_options = b'\202\323\344\223\002\017\022\r/v1/mcp/tools'
  _globals['_NODUSSERVICE'].methods_by_name['CheckHealth']._loaded_options = None
  _globals['_NODUSSERVICE'].methods_by_name['CheckHealth']._serialized_options = b'\202\323\344\223\002\014\022\n/v1/health'
  _globals['_CHECKHEALTHREQUEST']._serialized_start=157
  _globals['_CHECKHEALTHREQUEST']._serialized_end=203
  _globals['_CHECKHEALTHRESPONSE']._serialized_start=206
  _globals['_CHECKHEALTHRESPONSE']._serialized_end=424
  _globals['_CHECKHEALTHRESPONSE_SERVINGSTATUS']._serialized_start=309
  _globals['_CHECKHEALTHRESPONSE_SERVINGSTATUS']._serialized_end=424
  _globals['_NODUSSERVICE']._serialized_start=427
  _globals['_NODUSSERVICE']._serialized_end=1223
# @@protoc_insertion_point(module_scope)
